// The normal wrappers CommandLineFlags::boolAt and CommandLineFlags::intxAt skip constant flags
static bool boolAt(char* name, bool* value) {
  Flag* result = Flag::find_flag(name, strlen(name), true, true);
  if (result == NULL) return false;
  if (!result->is_bool()) return false;
  *value = result->get_bool();
  return true;
}

static bool intxAt(char* name, intx* value) {
  Flag* result = Flag::find_flag(name, strlen(name), true, true);
  if (result == NULL) return false;
  if (!result->is_intx()) return false;
  *value = result->get_intx();
  return true;
}

#define set_boolean(name, value) vmconfig_oop->bool_field_put(fs.offset(), value)
#define set_byte(name, value) vmconfig_oop->byte_field_put(fs.offset(), (jbyte)(value))
#define set_short(name, value) vmconfig_oop->short_field_put(fs.offset(), (jshort)(value))
#define set_int(name, value) vmconfig_oop->int_field_put(fs.offset(), (int)(value))
#define set_long(name, value) vmconfig_oop->long_field_put(fs.offset(), value)
#define set_address(name, value) do { set_long(name, (jlong)(value)); } while (0)

#define set_optional_boolean_flag(varName, flagName) do { bool flagValue; if (boolAt((char*) flagName, &flagValue)) { set_boolean(varName, flagValue); } } while (0)
#define set_optional_int_flag(varName, flagName) do { intx flagValue; if (intxAt((char*) flagName, &flagValue)) { set_int(varName, flagValue); } } while (0)
#define set_optional_long_flag(varName, flagName) do { intx flagValue; if (intxAt((char*) flagName, &flagValue)) { set_long(varName, flagValue); } } while (0)

void VMStructs::initHotSpotVMConfig(oop vmconfig_oop) {
  InstanceKlass* vmconfig_klass = InstanceKlass::cast(vmconfig_oop->klass());

  int expected = 450;
#if defined(TARGET_OS_FAMILY_bsd) || defined(TARGET_OS_FAMILY_linux)
  expected += 1;
#endif
#if defined(AMD64)
  expected += 31;
#endif
#if defined(SPARC)
  expected += 6;
#endif
  int assigned = 0;
  for (JavaFieldStream fs(vmconfig_klass); !fs.done(); fs.next()) {
    if (fs.signature() == vmSymbols::bool_signature()) {
      switch (fs.name()->utf8_length()) {
        case 32:
          if (fs.name()->equals("useCountTrailingZerosInstruction")) {
#if defined(AMD64)
            set_boolean("useCountTrailingZerosInstruction", UseCountTrailingZerosInstruction);
            assigned++;
#endif
            continue;
          }
          continue;
        case 35:
          if (fs.name()->equals("inlineContiguousAllocationSupported")) {
            set_boolean("inlineContiguousAllocationSupported",  !CMSIncrementalMode && Universe::heap()->supports_inline_contig_alloc());
            assigned++;
            continue;
          }
          continue;
        case 6:
          if (fs.name()->equals("ciTime")) {
            set_boolean("ciTime", CITime);
            assigned++;
            continue;
          }
          continue;
        case 7:
          if (fs.name()->equals("useTLAB")) {
            set_boolean("useTLAB", UseTLAB);
            assigned++;
            continue;
          }
          if (fs.name()->equals("useG1GC")) {
            set_boolean("useG1GC", UseG1GC);
            assigned++;
            continue;
          }
          continue;
        case 8:
          if (fs.name()->equals("useCMSGC")) {
            set_boolean("useCMSGC", UseConcMarkSweepGC);
            assigned++;
            continue;
          }
          continue;
        case 9:
          if (fs.name()->equals("tlabStats")) {
            set_boolean("tlabStats", TLABStats);
            assigned++;
            continue;
          }
          continue;
        case 10:
          if (fs.name()->equals("ciTimeEach")) {
            set_boolean("ciTimeEach", CITimeEach);
            assigned++;
            continue;
          }
          if (fs.name()->equals("verifyOops")) {
            set_boolean("verifyOops", VerifyOops);
            assigned++;
            continue;
          }
          continue;
        case 11:
          if (fs.name()->equals("cAssertions")) {
            set_boolean("cAssertions", DEBUG_ONLY(1) NOT_DEBUG(0));
            assigned++;
            continue;
          }
          continue;
        case 13:
          if (fs.name()->equals("printInlining")) {
            set_boolean("printInlining", PrintInlining);
            assigned++;
            continue;
          }
          continue;
        case 14:
          if (fs.name()->equals("useFastLocking")) {
            set_boolean("useFastLocking", JVMCIUseFastLocking);
            assigned++;
            continue;
          }
          if (fs.name()->equals("flightRecorder")) {
            set_optional_boolean_flag("flightRecorder",  "FlightRecorder");
            continue;
          }
          continue;
        case 15:
          if (fs.name()->equals("useStackBanging")) {
            set_boolean("useStackBanging", UseStackBanging);
            assigned++;
            continue;
          }
          if (fs.name()->equals("useHeapProfiler")) {
            set_boolean("useHeapProfiler", JVMCIHProfEnabled);
            assigned++;
            continue;
          }
          continue;
        case 16:
          if (fs.name()->equals("useBiasedLocking")) {
            set_boolean("useBiasedLocking", UseBiasedLocking);
            assigned++;
            continue;
          }
          if (fs.name()->equals("useAESIntrinsics")) {
            set_boolean("useAESIntrinsics", UseAESIntrinsics);
            assigned++;
            continue;
          }
          if (fs.name()->equals("forceUnreachable")) {
            set_boolean("forceUnreachable", ForceUnreachable);
            assigned++;
            continue;
          }
          continue;
        case 17:
          if (fs.name()->equals("useCompressedOops")) {
            set_boolean("useCompressedOops", UseCompressedOops);
            assigned++;
            continue;
          }
          continue;
        case 18:
          if (fs.name()->equals("useCRC32Intrinsics")) {
            set_boolean("useCRC32Intrinsics", UseCRC32Intrinsics);
            assigned++;
            continue;
          }
          continue;
        case 22:
          if (fs.name()->equals("usePopCountInstruction")) {
            set_boolean("usePopCountInstruction", UsePopCountInstruction);
            assigned++;
            continue;
          }
          if (fs.name()->equals("dontCompileHugeMethods")) {
            set_boolean("dontCompileHugeMethods", DontCompileHugeMethods);
            assigned++;
            continue;
          }
          continue;
        case 23:
          if (fs.name()->equals("useDeferredInitBarriers")) {
            set_boolean("useDeferredInitBarriers", JVMCIDeferredInitBarriers);
            assigned++;
            continue;
          }
          continue;
        case 26:
          if (fs.name()->equals("useCompressedClassPointers")) {
            set_boolean("useCompressedClassPointers", UseCompressedClassPointers);
            assigned++;
            continue;
          }
          continue;
        case 31:
          if (fs.name()->equals("useCountLeadingZerosInstruction")) {
#if defined(AMD64)
            set_boolean("useCountLeadingZerosInstruction", UseCountLeadingZerosInstruction);
            assigned++;
#endif
            continue;
          }
          continue;
      } // switch
      continue;
    } // if
    if (fs.signature() == vmSymbols::byte_signature()) {
      switch (fs.name()->utf8_length()) {
        case 16:
          if (fs.name()->equals("g1YoungCardValue")) {
            set_byte("g1YoungCardValue", (jbyte)G1SATBCardTableModRefBS::g1_young_card_val());
            assigned++;
            continue;
          }
          continue;
        case 14:
          if (fs.name()->equals("dirtyCardValue")) {
            set_byte("dirtyCardValue", (jbyte)CardTableModRefBS::dirty_card_val());
            assigned++;
            continue;
          }
          continue;
      } // switch
      continue;
    } // if
    if (fs.signature() == vmSymbols::int_signature()) {
      switch (fs.name()->utf8_length()) {
        case 5:
          if (fs.name()->equals("cpuHT")) {
#if defined(AMD64)
            set_int("cpuHT", VM_Version::CPU_HT);
            assigned++;
#endif
            continue;
          }
          continue;
        case 6:
          if (fs.name()->equals("cpuSSE")) {
#if defined(AMD64)
            set_int("cpuSSE", VM_Version::CPU_SSE);
            assigned++;
#endif
            continue;
          }
          if (fs.name()->equals("useSSE")) {
            set_int("useSSE", UseSSE);
            assigned++;
            continue;
          }
          if (fs.name()->equals("cpuCX8")) {
#if defined(AMD64)
            set_int("cpuCX8", VM_Version::CPU_CX8);
            assigned++;
#endif
            continue;
          }
          if (fs.name()->equals("cpuAES")) {
#if defined(AMD64)
            set_int("cpuAES", VM_Version::CPU_AES);
            assigned++;
#endif
            continue;
          }
          if (fs.name()->equals("cpuTSC")) {
#if defined(AMD64)
            set_int("cpuTSC", VM_Version::CPU_TSC);
            assigned++;
#endif
            continue;
          }
          if (fs.name()->equals("useAVX")) {
#if defined(AMD64)
            set_int("useAVX", UseAVX);
            assigned++;
#endif
            continue;
          }
          if (fs.name()->equals("cpuMMX")) {
#if defined(AMD64)
            set_int("cpuMMX", VM_Version::CPU_MMX);
            assigned++;
#endif
            continue;
          }
          if (fs.name()->equals("cpuAVX")) {
#if defined(AMD64)
            set_int("cpuAVX", VM_Version::CPU_AVX);
            assigned++;
#endif
            continue;
          }
          continue;
        case 7:
          if (fs.name()->equals("cpuAVX2")) {
#if defined(AMD64)
            set_int("cpuAVX2", VM_Version::CPU_AVX2);
            assigned++;
#endif
            continue;
          }
          if (fs.name()->equals("cpuERMS")) {
#if defined(AMD64)
            set_int("cpuERMS", VM_Version::CPU_ERMS);
            assigned++;
#endif
            continue;
          }
          if (fs.name()->equals("cpuSSE3")) {
#if defined(AMD64)
            set_int("cpuSSE3", VM_Version::CPU_SSE3);
            assigned++;
#endif
            continue;
          }
          if (fs.name()->equals("cpuSSE2")) {
#if defined(AMD64)
            set_int("cpuSSE2", VM_Version::CPU_SSE2);
            assigned++;
#endif
            continue;
          }
          if (fs.name()->equals("cpuBMI1")) {
#if defined(AMD64)
            set_int("cpuBMI1", VM_Version::CPU_BMI1);
            assigned++;
#endif
            continue;
          }
          if (fs.name()->equals("cpuFXSR")) {
#if defined(AMD64)
            set_int("cpuFXSR", VM_Version::CPU_FXSR);
            assigned++;
#endif
            continue;
          }
          if (fs.name()->equals("cpuCMOV")) {
#if defined(AMD64)
            set_int("cpuCMOV", VM_Version::CPU_CMOV);
            assigned++;
#endif
            continue;
          }
          continue;
        case 8:
          if (fs.name()->equals("cpuSSSE3")) {
#if defined(AMD64)
            set_int("cpuSSSE3", VM_Version::CPU_SSSE3);
            assigned++;
#endif
            continue;
          }
          if (fs.name()->equals("cpuLZCNT")) {
#if defined(AMD64)
            set_int("cpuLZCNT", VM_Version::CPU_LZCNT);
            assigned++;
#endif
            continue;
          }
          if (fs.name()->equals("cpuCLMUL")) {
#if defined(AMD64)
            set_int("cpuCLMUL", VM_Version::CPU_CLMUL);
            assigned++;
#endif
            continue;
          }
          if (fs.name()->equals("cpuSSE42")) {
#if defined(AMD64)
            set_int("cpuSSE42", VM_Version::CPU_SSE4_2);
            assigned++;
#endif
            continue;
          }
          if (fs.name()->equals("cpuSSE41")) {
#if defined(AMD64)
            set_int("cpuSSE41", VM_Version::CPU_SSE4_1);
            assigned++;
#endif
            continue;
          }
          if (fs.name()->equals("cpuSSE4A")) {
#if defined(AMD64)
            set_int("cpuSSE4A", VM_Version::CPU_SSE4A);
            assigned++;
#endif
            continue;
          }
          continue;
        case 9:
          if (fs.name()->equals("cpuTSCINV")) {
#if defined(AMD64)
            set_int("cpuTSCINV", VM_Version::CPU_TSCINV);
            assigned++;
#endif
            continue;
          }
          if (fs.name()->equals("cpuPOPCNT")) {
#if defined(AMD64)
            set_int("cpuPOPCNT", VM_Version::CPU_POPCNT);
            assigned++;
#endif
            continue;
          }
          if (fs.name()->equals("stackBias")) {
            set_int("stackBias", STACK_BIAS);
            assigned++;
            continue;
          }
          if (fs.name()->equals("hubOffset")) {
            set_int("hubOffset", offset_of(oopDesc, _metadata._klass));
            assigned++;
            continue;
          }
          continue;
        case 10:
          if (fs.name()->equals("markOffset")) {
            set_int("markOffset", offset_of(oopDesc, _mark));
            assigned++;
            continue;
          }
          continue;
        case 11:
          if (fs.name()->equals("klassOffset")) {
            set_int("klassOffset", (int) (intptr_t) java_lang_Class::_klass_offset);
            assigned++;
            continue;
          }
          continue;
        case 12:
          if (fs.name()->equals("unlockedMask")) {
            set_int("unlockedMask", markOopDesc::unlocked_value);
            assigned++;
            continue;
          }
          if (fs.name()->equals("heapWordSize")) {
            set_int("heapWordSize", HeapWordSize);
            assigned++;
            continue;
          }
          continue;
        case 13:
          if (fs.name()->equals("syntheticFlag")) {
            set_int("syntheticFlag", JVM_ACC_SYNTHETIC);
            assigned++;
            continue;
          }
          if (fs.name()->equals("sparcFeatures")) {
#if defined(SPARC)
            set_int("sparcFeatures", (int) (intptr_t) VM_Version::_features);
            assigned++;
#endif
            continue;
          }
          if (fs.name()->equals("basicLockSize")) {
            set_int("basicLockSize", sizeof(BasicLock));
            assigned++;
            continue;
          }
          continue;
        case 14:
          if (fs.name()->equals("narrowOopShift")) {
            set_int("narrowOopShift", (int) (intptr_t) Universe::_narrow_oop._shift);
            assigned++;
            continue;
          }
          if (fs.name()->equals("methodDataSize")) {
            set_int("methodDataSize", offset_of(MethodData, _size));
            assigned++;
            continue;
          }
          if (fs.name()->equals("x86CPUFeatures")) {
#if defined(AMD64)
            set_int("x86CPUFeatures", (int) (intptr_t) VM_Version::_cpuFeatures);
            assigned++;
#endif
            continue;
          }
          if (fs.name()->equals("osThreadOffset")) {
            set_int("osThreadOffset", offset_of(JavaThread, _osthread));
            assigned++;
            continue;
          }
          if (fs.name()->equals("ageMaskInPlace")) {
            set_int("ageMaskInPlace", markOopDesc::age_mask_in_place);
            assigned++;
            continue;
          }
          if (fs.name()->equals("subklassOffset")) {
            set_int("subklassOffset", offset_of(Klass, _subklass));
            assigned++;
            continue;
          }
          continue;
        case 15:
          if (fs.name()->equals("vtableEntrySize")) {
            set_int("vtableEntrySize", sizeof(vtableEntry));
            assigned++;
            continue;
          }
          if (fs.name()->equals("MARKID_POLL_FAR")) {
            set_int("MARKID_POLL_FAR", CodeInstaller::POLL_FAR);
            assigned++;
            continue;
          }
          if (fs.name()->equals("jvmConstantLong")) {
            set_int("jvmConstantLong", JVM_CONSTANT_Long);
            assigned++;
            continue;
          }
          if (fs.name()->equals("deoptActionNone")) {
            set_int("deoptActionNone", Deoptimization::Action_none);
            assigned++;
            continue;
          }
          if (fs.name()->equals("hugeMethodLimit")) {
            set_int("hugeMethodLimit", HugeMethodLimit);
            assigned++;
            continue;
          }
          if (fs.name()->equals("dataLayoutNoTag")) {
            set_int("dataLayoutNoTag", DataLayout::no_tag);
            assigned++;
            continue;
          }
          if (fs.name()->equals("bciProfileWidth")) {
            set_int("bciProfileWidth", BciProfileWidth);
            assigned++;
            continue;
          }
          if (fs.name()->equals("jvmConstantUtf8")) {
            set_int("jvmConstantUtf8", JVM_CONSTANT_Utf8);
            assigned++;
            continue;
          }
          if (fs.name()->equals("deoptReasonNone")) {
            set_int("deoptReasonNone", Deoptimization::Reason_none);
            assigned++;
            continue;
          }
          if (fs.name()->equals("objectAlignment")) {
            set_int("objectAlignment", ObjectAlignmentInBytes);
            assigned++;
            continue;
          }
          if (fs.name()->equals("barrierSetOther")) {
            set_int("barrierSetOther", BarrierSet::Other);
            assigned++;
            continue;
          }
          continue;
        case 16:
          if (fs.name()->equals("cpu3DNOWPREFETCH")) {
#if defined(AMD64)
            set_int("cpu3DNOWPREFETCH", VM_Version::CPU_3DNOW_PREFETCH);
            assigned++;
#endif
            continue;
          }
          if (fs.name()->equals("stackShadowPages")) {
            set_int("stackShadowPages", StackShadowPages);
            assigned++;
            continue;
          }
          if (fs.name()->equals("methodCodeOffset")) {
            set_int("methodCodeOffset", offset_of(Method, _code));
            assigned++;
            continue;
          }
          if (fs.name()->equals("vis1Instructions")) {
#if defined(SPARC)
            set_int("vis1Instructions", VM_Version::vis1_instructions_m);
            assigned++;
#endif
            continue;
          }
          if (fs.name()->equals("vis3Instructions")) {
#if defined(SPARC)
            set_int("vis3Instructions", VM_Version::vis3_instructions_m);
            assigned++;
#endif
            continue;
          }
          if (fs.name()->equals("barrierSetModRef")) {
            set_int("barrierSetModRef", BarrierSet::ModRef);
            assigned++;
            continue;
          }
          if (fs.name()->equals("epochMaskInPlace")) {
            set_int("epochMaskInPlace", markOopDesc::epoch_mask_in_place);
            assigned++;
            continue;
          }
          if (fs.name()->equals("fieldInfoTagSize")) {
            set_int("fieldInfoTagSize", FIELDINFO_TAG_SIZE);
            assigned++;
            continue;
          }
          if (fs.name()->equals("constantPoolSize")) {
            set_int("constantPoolSize", sizeof(ConstantPool));
            assigned++;
            continue;
          }
          if (fs.name()->equals("baseVtableLength")) {
            set_int("baseVtableLength", Universe::base_vtable_size() / vtableEntry::size());
            assigned++;
            continue;
          }
          if (fs.name()->equals("vis2Instructions")) {
#if defined(SPARC)
            set_int("vis2Instructions", VM_Version::vis2_instructions_m);
            assigned++;
#endif
            continue;
          }
          if (fs.name()->equals("MARKID_POLL_NEAR")) {
            set_int("MARKID_POLL_NEAR", CodeInstaller::POLL_NEAR);
            assigned++;
            continue;
          }
          if (fs.name()->equals("typeProfileWidth")) {
            set_int("typeProfileWidth", TypeProfileWidth);
            assigned++;
            continue;
          }
          if (fs.name()->equals("narrowKlassShift")) {
            set_int("narrowKlassShift", (int) (intptr_t) Universe::_narrow_klass._shift);
            assigned++;
            continue;
          }
          if (fs.name()->equals("jvmConstantFloat")) {
            set_int("jvmConstantFloat", JVM_CONSTANT_Float);
            assigned++;
            continue;
          }
          if (fs.name()->equals("threadTlabOffset")) {
            set_int("threadTlabOffset", offset_of(Thread, _tlab));
            assigned++;
            continue;
          }
          if (fs.name()->equals("arrayKlassOffset")) {
            set_int("arrayKlassOffset", (int) (intptr_t) java_lang_Class::_array_klass_offset);
            assigned++;
            continue;
          }
          if (fs.name()->equals("MARKID_OSR_ENTRY")) {
            set_int("MARKID_OSR_ENTRY", CodeInstaller::OSR_ENTRY);
            assigned++;
            continue;
          }
          if (fs.name()->equals("methodDataOffset")) {
            set_int("methodDataOffset", offset_of(Method, _method_data));
            assigned++;
            continue;
          }
          if (fs.name()->equals("jvmConstantClass")) {
            set_int("jvmConstantClass", JVM_CONSTANT_Class);
            assigned++;
            continue;
          }
          if (fs.name()->equals("symbolBodyOffset")) {
            set_int("symbolBodyOffset", offset_of(Symbol, _body[0]));
            assigned++;
            continue;
          }
          continue;
        case 17:
          if (fs.name()->equals("jvmConstantDouble")) {
            set_int("jvmConstantDouble", JVM_CONSTANT_Double);
            assigned++;
            continue;
          }
          if (fs.name()->equals("nextSiblingOffset")) {
            set_int("nextSiblingOffset", offset_of(Klass, _next_sibling));
            assigned++;
            continue;
          }
          if (fs.name()->equals("logOfHRGrainBytes")) {
            set_int("logOfHRGrainBytes", (int) (intptr_t) HeapRegion::LogOfHRGrainBytes);
            assigned++;
            continue;
          }
          if (fs.name()->equals("arrayU1DataOffset")) {
            set_int("arrayU1DataOffset", offset_of(Array<u1>, _data));
            assigned++;
            continue;
          }
          if (fs.name()->equals("methodFlagsHidden")) {
            set_int("methodFlagsHidden", Method::_hidden);
            assigned++;
            continue;
          }
          if (fs.name()->equals("classMirrorOffset")) {
            set_int("classMirrorOffset", offset_of(Klass, _java_mirror));
            assigned++;
            continue;
          }
          if (fs.name()->equals("vmSymbolsSIDLimit")) {
            set_int("vmSymbolsSIDLimit", vmSymbols::SID_LIMIT);
            assigned++;
            continue;
          }
          if (fs.name()->equals("symbolPointerSize")) {
            set_int("symbolPointerSize", sizeof(Symbol*));
            assigned++;
            continue;
          }
          if (fs.name()->equals("arrayU2DataOffset")) {
            set_int("arrayU2DataOffset", offset_of(Array<u2>, _data));
            assigned++;
            continue;
          }
          if (fs.name()->equals("methodFlagsOffset")) {
            set_int("methodFlagsOffset", offset_of(Method, _flags));
            assigned++;
            continue;
          }
          if (fs.name()->equals("arrayLengthOffset")) {
            set_int("arrayLengthOffset", arrayOopDesc::length_offset_in_bytes());
            assigned++;
            continue;
          }
          if (fs.name()->equals("extraStackEntries")) {
            set_int("extraStackEntries", Method::extra_stack_entries());
            assigned++;
            continue;
          }
          if (fs.name()->equals("vmSymbolsFirstSID")) {
            set_int("vmSymbolsFirstSID", vmSymbols::FIRST_SID);
            assigned++;
            continue;
          }
          if (fs.name()->equals("biasedLockPattern")) {
            set_int("biasedLockPattern", markOopDesc::biased_lock_pattern);
            assigned++;
            continue;
          }
          if (fs.name()->equals("jvmConstantString")) {
            set_int("jvmConstantString", JVM_CONSTANT_String);
            assigned++;
            continue;
          }
          if (fs.name()->equals("jvmAccFieldStable")) {
            set_int("jvmAccFieldStable", JVM_ACC_FIELD_STABLE);
            assigned++;
            continue;
          }
          if (fs.name()->equals("jvmciCountersSize")) {
            set_int("jvmciCountersSize", (jint) JVMCICounterSize);
            assigned++;
            continue;
          }
          if (fs.name()->equals("logKlassAlignment")) {
            set_int("logKlassAlignment", LogKlassAlignmentInBytes);
            assigned++;
            continue;
          }
          continue;
        case 18:
          if (fs.name()->equals("invocationEntryBci")) {
            set_int("invocationEntryBci", InvocationEntryBci);
            assigned++;
            continue;
          }
          if (fs.name()->equals("threadObjectOffset")) {
            set_int("threadObjectOffset", offset_of(JavaThread, _threadObj));
            assigned++;
            continue;
          }
          if (fs.name()->equals("dataLayoutCellSize")) {
            set_int("dataLayoutCellSize", DataLayout::cell_size);
            assigned++;
            continue;
          }
          if (fs.name()->equals("codeEntryAlignment")) {
            set_int("codeEntryAlignment", CodeEntryAlignment);
            assigned++;
            continue;
          }
          if (fs.name()->equals("methodProfileWidth")) {
            set_int("methodProfileWidth", MethodProfileWidth);
            assigned++;
            continue;
          }
          if (fs.name()->equals("jvmciEnvTaskOffset")) {
            set_int("jvmciEnvTaskOffset", offset_of(JVMCIEnv, _task));
            assigned++;
            continue;
          }
          if (fs.name()->equals("cbcondInstructions")) {
#if defined(SPARC)
            set_int("cbcondInstructions", VM_Version::cbcond_instructions_m);
            assigned++;
#endif
            continue;
          }
          if (fs.name()->equals("methodDataDataSize")) {
            set_int("methodDataDataSize", offset_of(MethodData, _data_size));
            assigned++;
            continue;
          }
          if (fs.name()->equals("nmethodEntryOffset")) {
            set_int("nmethodEntryOffset", offset_of(nmethod, _verified_entry_point));
            assigned++;
            continue;
          }
          if (fs.name()->equals("barrierSetG1SATBCT")) {
            set_int("barrierSetG1SATBCT", BarrierSet::G1SATBCT);
            assigned++;
            continue;
          }
          if (fs.name()->equals("invalidVtableIndex")) {
            set_int("invalidVtableIndex", Method::invalid_vtable_index);
            assigned++;
            continue;
          }
          if (fs.name()->equals("jvmAccWrittenFlags")) {
            set_int("jvmAccWrittenFlags", JVM_ACC_WRITTEN_FLAGS);
            assigned++;
            continue;
          }
          if (fs.name()->equals("jvmAccMonitorMatch")) {
            set_int("jvmAccMonitorMatch", JVM_ACC_MONITOR_MATCH);
            assigned++;
            continue;
          }
          if (fs.name()->equals("symbolLengthOffset")) {
            set_int("symbolLengthOffset", offset_of(Symbol, _length));
            assigned++;
            continue;
          }
          if (fs.name()->equals("jvmConstantInteger")) {
            set_int("jvmConstantInteger", JVM_CONSTANT_Integer);
            assigned++;
            continue;
          }
          continue;
        case 19:
          if (fs.name()->equals("MARKID_INVOKESTATIC")) {
            set_int("MARKID_INVOKESTATIC", CodeInstaller::INVOKESTATIC);
            assigned++;
            continue;
          }
          if (fs.name()->equals("jvmConstantFieldref")) {
            set_int("jvmConstantFieldref", JVM_CONSTANT_Fieldref);
            assigned++;
            continue;
          }
          if (fs.name()->equals("deoptReasonAliasing")) {
            set_int("deoptReasonAliasing", Deoptimization::Reason_aliasing);
            assigned++;
            continue;
          }
          if (fs.name()->equals("dataLayoutBCIOffset")) {
            set_int("dataLayoutBCIOffset", offset_of(DataLayout, _header._struct._bci));
            assigned++;
            continue;
          }
          if (fs.name()->equals("fieldInfoFieldSlots")) {
            set_int("fieldInfoFieldSlots", FieldInfo::field_slots);
            assigned++;
            continue;
          }
          if (fs.name()->equals("ptrQueueIndexOffset")) {
            set_int("ptrQueueIndexOffset", offset_of(PtrQueue, _index));
            assigned++;
            continue;
          }
          if (fs.name()->equals("arrayU1LengthOffset")) {
            set_int("arrayU1LengthOffset", offset_of(Array<int>, _length));
            assigned++;
            continue;
          }
          if (fs.name()->equals("jvmAccFieldInternal")) {
            set_int("jvmAccFieldInternal", JVM_ACC_FIELD_INTERNAL);
            assigned++;
            continue;
          }
          if (fs.name()->equals("codeInstallResultOk")) {
            set_int("codeInstallResultOk", JVMCIEnv::ok);
            assigned++;
            continue;
          }
          if (fs.name()->equals("dataLayoutTagOffset")) {
            set_int("dataLayoutTagOffset", offset_of(DataLayout, _header._struct._tag));
            assigned++;
            continue;
          }
          continue;
        case 20:
          if (fs.name()->equals("runtimeCallStackSize")) {
#if defined(AMD64)
            set_int("runtimeCallStackSize", frame::arg_reg_save_area_bytes);
            assigned++;
#endif
            continue;
          }
          if (fs.name()->equals("MARKID_INLINE_INVOKE")) {
            set_int("MARKID_INLINE_INVOKE", CodeInstaller::INLINE_INVOKE);
            assigned++;
            continue;
          }
          if (fs.name()->equals("ptrQueueActiveOffset")) {
            set_int("ptrQueueActiveOffset", offset_of(PtrQueue, _active));
            assigned++;
            continue;
          }
          if (fs.name()->equals("compilerToVMKlassTag")) {
            set_int("compilerToVMKlassTag", CompilerToVM::KLASS_TAG);
            assigned++;
            continue;
          }
          if (fs.name()->equals("dataLayoutHeaderSize")) {
            set_int("dataLayoutHeaderSize", DataLayout::cell_size);
            assigned++;
            continue;
          }
          if (fs.name()->equals("jvmConstantMethodref")) {
            set_int("jvmConstantMethodref", JVM_CONSTANT_Methodref);
            assigned++;
            continue;
          }
          if (fs.name()->equals("dataLayoutBitDataTag")) {
            set_int("dataLayoutBitDataTag", DataLayout::bit_data_tag);
            assigned++;
            continue;
          }
          if (fs.name()->equals("MARKID_INVOKESPECIAL")) {
            set_int("MARKID_INVOKESPECIAL", CodeInstaller::INVOKESPECIAL);
            assigned++;
            continue;
          }
          if (fs.name()->equals("ptrQueueBufferOffset")) {
            set_int("ptrQueueBufferOffset", offset_of(PtrQueue, _buf));
            assigned++;
            continue;
          }
          if (fs.name()->equals("dataLayoutRetDataTag")) {
            set_int("dataLayoutRetDataTag", DataLayout::ret_data_tag);
            assigned++;
            continue;
          }
          if (fs.name()->equals("deoptReasonOSROffset")) {
            set_int("deoptReasonOSROffset", Deoptimization::Reason_LIMIT);
            assigned++;
            continue;
          }
          if (fs.name()->equals("deoptReasonDiv0Check")) {
            set_int("deoptReasonDiv0Check", Deoptimization::Reason_div0_check);
            assigned++;
            continue;
          }
          if (fs.name()->equals("barrierSetKindOffset")) {
            set_int("barrierSetKindOffset", offset_of(BarrierSet, _kind));
            assigned++;
            continue;
          }
          if (fs.name()->equals("tlabAlignmentReserve")) {
            set_int("tlabAlignmentReserve", ThreadLocalAllocBuffer::alignment_reserve());
            assigned++;
            continue;
          }
          if (fs.name()->equals("codeHeapMemoryOffset")) {
            set_int("codeHeapMemoryOffset", offset_of(CodeHeap, _memory));
            assigned++;
            continue;
          }
          if (fs.name()->equals("deoptReasonNullCheck")) {
            set_int("deoptReasonNullCheck", Deoptimization::Reason_null_check);
            assigned++;
            continue;
          }
          if (fs.name()->equals("MARKID_INVOKEVIRTUAL")) {
            set_int("MARKID_INVOKEVIRTUAL", CodeInstaller::INVOKEVIRTUAL);
            assigned++;
            continue;
          }
          continue;
        case 21:
          if (fs.name()->equals("MARKID_INVOKE_INVALID")) {
            set_int("MARKID_INVOKE_INVALID", CodeInstaller::INVOKE_INVALID);
            assigned++;
            continue;
          }
          if (fs.name()->equals("deoptReasonClassCheck")) {
            set_int("deoptReasonClassCheck", Deoptimization::Reason_class_check);
            assigned++;
            continue;
          }
          if (fs.name()->equals("klassSuperKlassOffset")) {
            set_int("klassSuperKlassOffset", offset_of(Klass, _super));
            assigned++;
            continue;
          }
          if (fs.name()->equals("biasedLockMaskInPlace")) {
            set_int("biasedLockMaskInPlace", markOopDesc::biased_lock_mask_in_place);
            assigned++;
            continue;
          }
          if (fs.name()->equals("jvmConstantMethodType")) {
            set_int("jvmConstantMethodType", JVM_CONSTANT_MethodType);
            assigned++;
            continue;
          }
          if (fs.name()->equals("compilerToVMSymbolTag")) {
            set_int("compilerToVMSymbolTag", CompilerToVM::SYMBOL_TAG);
            assigned++;
            continue;
          }
          if (fs.name()->equals("allocatePrefetchStyle")) {
            set_int("allocatePrefetchStyle", AllocatePrefetchStyle);
            assigned++;
            continue;
          }
          if (fs.name()->equals("methodMaxLocalsOffset")) {
            set_int("methodMaxLocalsOffset", offset_of(ConstMethod, _max_locals));
            assigned++;
            continue;
          }
          if (fs.name()->equals("methodFlagsDontInline")) {
            set_int("methodFlagsDontInline", Method::_dont_inline);
            assigned++;
            continue;
          }
          if (fs.name()->equals("dataLayoutCellsOffset")) {
            set_int("dataLayoutCellsOffset", offset_of(DataLayout, _cells[0]));
            assigned++;
            continue;
          }
          if (fs.name()->equals("dataLayoutFlagsOffset")) {
            set_int("dataLayoutFlagsOffset", offset_of(DataLayout, _header._struct._flags));
            assigned++;
            continue;
          }
          if (fs.name()->equals("dataLayoutJumpDataTag")) {
            set_int("dataLayoutJumpDataTag", DataLayout::jump_data_tag);
            assigned++;
            continue;
          }
          if (fs.name()->equals("secondarySupersOffset")) {
            set_int("secondarySupersOffset", offset_of(Klass, _secondary_supers));
            assigned++;
            continue;
          }
          if (fs.name()->equals("deoptReasonUnresolved")) {
            set_int("deoptReasonUnresolved", Deoptimization::Reason_unresolved);
            assigned++;
            continue;
          }
          if (fs.name()->equals("MARKID_VERIFIED_ENTRY")) {
            set_int("MARKID_VERIFIED_ENTRY", CodeInstaller::VERIFIED_ENTRY);
            assigned++;
            continue;
          }
          if (fs.name()->equals("deoptReasonArrayCheck")) {
            set_int("deoptReasonArrayCheck", Deoptimization::Reason_array_check);
            assigned++;
            continue;
          }
          if (fs.name()->equals("deoptReasonUnreached0")) {
            set_int("deoptReasonUnreached0", Deoptimization::Reason_unreached0);
            assigned++;
            continue;
          }
          if (fs.name()->equals("identityHashCodeShift")) {
            set_int("identityHashCodeShift", markOopDesc::hash_shift);
            assigned++;
            continue;
          }
          if (fs.name()->equals("deoptReasonRangeCheck")) {
            set_int("deoptReasonRangeCheck", Deoptimization::Reason_range_check);
            assigned++;
            continue;
          }
          if (fs.name()->equals("nonvirtualVtableIndex")) {
            set_int("nonvirtualVtableIndex", Method::nonvirtual_vtable_index);
            assigned++;
            continue;
          }
          if (fs.name()->equals("allocatePrefetchInstr")) {
            set_int("allocatePrefetchInstr", AllocatePrefetchInstr);
            assigned++;
            continue;
          }
          if (fs.name()->equals("methodFlagsJfrTowrite")) {
            set_int("methodFlagsJfrTowrite", Method::_jfr_towrite);
            assigned++;
            continue;
          }
          if (fs.name()->equals("klassHasFinalizerFlag")) {
            set_int("klassHasFinalizerFlag", JVM_ACC_HAS_FINALIZER);
            assigned++;
            continue;
          }
          if (fs.name()->equals("compileTheWorldStopAt")) {
            set_optional_int_flag("compileTheWorldStopAt",  "CompileTheWorldStopAt");
            continue;
          }
          if (fs.name()->equals("markWordNoLockInPlace")) {
            set_int("markWordNoLockInPlace", markOopDesc::no_lock_in_place);
            assigned++;
            continue;
          }
          if (fs.name()->equals("allocatePrefetchLines")) {
            set_int("allocatePrefetchLines", AllocatePrefetchLines);
            assigned++;
            continue;
          }
          if (fs.name()->equals("deoptReasonConstraint")) {
            set_int("deoptReasonConstraint", Deoptimization::Reason_constraint);
            assigned++;
            continue;
          }
          if (fs.name()->equals("markWordNoHashInPlace")) {
            set_int("markWordNoHashInPlace", markOopDesc::no_hash_in_place);
            assigned++;
            continue;
          }
          continue;
        case 22:
          if (fs.name()->equals("deoptActionReinterpret")) {
            set_int("deoptActionReinterpret", Deoptimization::Action_reinterpret);
            assigned++;
            continue;
          }
          if (fs.name()->equals("compileTheWorldStartAt")) {
            set_optional_int_flag("compileTheWorldStartAt",  "CompileTheWorldStartAt");
            continue;
          }
          if (fs.name()->equals("vmIntrinsicInvokeBasic")) {
            set_int("vmIntrinsicInvokeBasic", vmIntrinsics::_invokeBasic);
            assigned++;
            continue;
          }
          if (fs.name()->equals("superCheckOffsetOffset")) {
            set_int("superCheckOffsetOffset", offset_of(Klass, _super_check_offset));
            assigned++;
            continue;
          }
          if (fs.name()->equals("MARKID_INVOKEINTERFACE")) {
            set_int("MARKID_INVOKEINTERFACE", CodeInstaller::INVOKEINTERFACE);
            assigned++;
            continue;
          }
          if (fs.name()->equals("deoptReasonJsrMismatch")) {
            set_int("deoptReasonJsrMismatch", Deoptimization::Reason_jsr_mismatch);
            assigned++;
            continue;
          }
          if (fs.name()->equals("jvmConstantNameAndType")) {
            set_int("jvmConstantNameAndType", JVM_CONSTANT_NameAndType);
            assigned++;
            continue;
          }
          if (fs.name()->equals("constantPoolTagsOffset")) {
            set_int("constantPoolTagsOffset", offset_of(ConstantPool, _tags));
            assigned++;
            continue;
          }
          if (fs.name()->equals("jvmConstantInternalMax")) {
            set_int("jvmConstantInternalMax", JVM_CONSTANT_InternalMax);
            assigned++;
            continue;
          }
          if (fs.name()->equals("methodFlagsForceInline")) {
            set_int("methodFlagsForceInline", Method::_force_inline);
            assigned++;
            continue;
          }
          if (fs.name()->equals("nmethodCompLevelOffset")) {
            set_int("nmethodCompLevelOffset", offset_of(nmethod, _comp_level));
            assigned++;
            continue;
          }
          if (fs.name()->equals("MARKID_POLL_RETURN_FAR")) {
            set_int("MARKID_POLL_RETURN_FAR", CodeInstaller::POLL_RETURN_FAR);
            assigned++;
            continue;
          }
          if (fs.name()->equals("constMethodFlagsOffset")) {
            set_int("constMethodFlagsOffset", offset_of(ConstMethod, _flags));
            assigned++;
            continue;
          }
          if (fs.name()->equals("jvmConstantExternalMax")) {
            set_int("jvmConstantExternalMax", JVM_CONSTANT_ExternalMax);
            assigned++;
            continue;
          }
          if (fs.name()->equals("klassAccessFlagsOffset")) {
            set_int("klassAccessFlagsOffset", offset_of(Klass, _access_flags));
            assigned++;
            continue;
          }
          if (fs.name()->equals("jvmConstantInternalMin")) {
            set_int("jvmConstantInternalMin", JVM_CONSTANT_InternalMin);
            assigned++;
            continue;
          }
          if (fs.name()->equals("methodDataIRSizeOffset")) {
            set_int("methodDataIRSizeOffset", offset_of(MethodData, _jvmci_ir_size));
            assigned++;
            continue;
          }
          if (fs.name()->equals("pendingExceptionOffset")) {
            set_int("pendingExceptionOffset", offset_of(ThreadShadow, _pending_exception));
            assigned++;
            continue;
          }
          if (fs.name()->equals("javaThreadAnchorOffset")) {
            set_int("javaThreadAnchorOffset", offset_of(JavaThread, _anchor));
            assigned++;
            continue;
          }
          continue;
        case 23:
          if (fs.name()->equals("klassLayoutHelperOffset")) {
            set_int("klassLayoutHelperOffset", offset_of(Klass, _layout_helper));
            assigned++;
            continue;
          }
          if (fs.name()->equals("methodConstMethodOffset")) {
            set_int("methodConstMethodOffset", offset_of(Method, _constMethod));
            assigned++;
            continue;
          }
          if (fs.name()->equals("jvmConstantMethodHandle")) {
            set_int("jvmConstantMethodHandle", JVM_CONSTANT_MethodHandle);
            assigned++;
            continue;
          }
          if (fs.name()->equals("dataLayoutBranchDataTag")) {
            set_int("dataLayoutBranchDataTag", DataLayout::branch_data_tag);
            assigned++;
            continue;
          }
          if (fs.name()->equals("methodDataOopDataOffset")) {
            set_int("methodDataOopDataOffset", offset_of(MethodData, _data[0]));
            assigned++;
            continue;
          }
          if (fs.name()->equals("threadExceptionPcOffset")) {
            set_int("threadExceptionPcOffset", offset_of(JavaThread, _exception_pc));
            assigned++;
            continue;
          }
          if (fs.name()->equals("methodAccessFlagsOffset")) {
            set_int("methodAccessFlagsOffset", offset_of(Method, _access_flags));
            assigned++;
            continue;
          }
          if (fs.name()->equals("methodIntrinsicIdOffset")) {
            set_int("methodIntrinsicIdOffset", offset_of(Method, _intrinsic_id));
            assigned++;
            continue;
          }
          if (fs.name()->equals("MARKID_CARD_TABLE_SHIFT")) {
            set_int("MARKID_CARD_TABLE_SHIFT", CodeInstaller::CARD_TABLE_SHIFT);
            assigned++;
            continue;
          }
          if (fs.name()->equals("methodVtableIndexOffset")) {
            set_int("methodVtableIndexOffset", offset_of(Method, _vtable_index));
            assigned++;
            continue;
          }
          if (fs.name()->equals("MARKID_UNVERIFIED_ENTRY")) {
            set_int("MARKID_UNVERIFIED_ENTRY", CodeInstaller::UNVERIFIED_ENTRY);
            assigned++;
            continue;
          }
          if (fs.name()->equals("vmIntrinsicLinkToStatic")) {
            set_int("vmIntrinsicLinkToStatic", vmIntrinsics::_linkToStatic);
            assigned++;
            continue;
          }
          if (fs.name()->equals("vtableEntryMethodOffset")) {
            set_int("vtableEntryMethodOffset", offset_of(vtableEntry, _method));
            assigned++;
            continue;
          }
          if (fs.name()->equals("MARKID_POLL_RETURN_NEAR")) {
            set_int("MARKID_POLL_RETURN_NEAR", CodeInstaller::POLL_RETURN_NEAR);
            assigned++;
            continue;
          }
          if (fs.name()->equals("arrayClassElementOffset")) {
            set_int("arrayClassElementOffset", offset_of(ObjArrayKlass, _element_klass));
            assigned++;
            continue;
          }
          if (fs.name()->equals("prototypeMarkWordOffset")) {
            set_int("prototypeMarkWordOffset", offset_of(Klass, _prototype_header));
            assigned++;
            continue;
          }
          continue;
        case 24:
          if (fs.name()->equals("constantPoolLengthOffset")) {
            set_int("constantPoolLengthOffset", offset_of(ConstantPool, _length));
            assigned++;
            continue;
          }
          if (fs.name()->equals("dataLayoutArgInfoDataTag")) {
            set_int("dataLayoutArgInfoDataTag", DataLayout::arg_info_data_tag);
            assigned++;
            continue;
          }
          if (fs.name()->equals("instanceKlassStateLinked")) {
            set_int("instanceKlassStateLinked", InstanceKlass::linked);
            assigned++;
            continue;
          }
          if (fs.name()->equals("tlabRefillWasteIncrement")) {
            set_int("tlabRefillWasteIncrement", TLABWasteIncrement);
            assigned++;
            continue;
          }
          if (fs.name()->equals("metaspaceArrayBaseOffset")) {
            set_int("metaspaceArrayBaseOffset", offset_of(Array<Klass*>, _data[0]));
            assigned++;
            continue;
          }
          if (fs.name()->equals("recognizedFieldModifiers")) {
            set_int("recognizedFieldModifiers", JVM_RECOGNIZED_FIELD_MODIFIERS);
            assigned++;
            continue;
          }
          if (fs.name()->equals("jvmConstantInvokeDynamic")) {
            set_int("jvmConstantInvokeDynamic", JVM_CONSTANT_InvokeDynamic);
            assigned++;
            continue;
          }
          if (fs.name()->equals("deoptimizationActionBits")) {
            set_int("deoptimizationActionBits", Deoptimization::_action_bits);
            assigned++;
            continue;
          }
          if (fs.name()->equals("allocatePrefetchDistance")) {
            set_int("allocatePrefetchDistance", AllocatePrefetchDistance);
            assigned++;
            continue;
          }
          if (fs.name()->equals("vmIntrinsicLinkToVirtual")) {
            set_int("vmIntrinsicLinkToVirtual", vmIntrinsics::_linkToVirtual);
            assigned++;
            continue;
          }
          if (fs.name()->equals("threadObjectResultOffset")) {
            set_int("threadObjectResultOffset", offset_of(JavaThread, _vm_result));
            assigned++;
            continue;
          }
          if (fs.name()->equals("fieldInfoLowPackedOffset")) {
            set_int("fieldInfoLowPackedOffset", FieldInfo::low_packed_offset);
            assigned++;
            continue;
          }
          if (fs.name()->equals("fieldInfoNameIndexOffset")) {
            set_int("fieldInfoNameIndexOffset", FieldInfo::name_index_offset);
            assigned++;
            continue;
          }
          if (fs.name()->equals("threadExceptionOopOffset")) {
            set_int("threadExceptionOopOffset", offset_of(JavaThread, _exception_oop));
            assigned++;
            continue;
          }
          if (fs.name()->equals("allocatePrefetchStepSize")) {
            set_int("allocatePrefetchStepSize", AllocatePrefetchStepSize);
            assigned++;
            continue;
          }
          if (fs.name()->equals("vmIntrinsicLinkToSpecial")) {
            set_int("vmIntrinsicLinkToSpecial", vmIntrinsics::_linkToSpecial);
            assigned++;
            continue;
          }
          if (fs.name()->equals("codeBlobCodeOffsetOffset")) {
            set_int("codeBlobCodeOffsetOffset", offset_of(CodeBlob, _code_offset));
            assigned++;
            continue;
          }
          if (fs.name()->equals("deoptimizationReasonBits")) {
            set_int("deoptimizationReasonBits", Deoptimization::_reason_bits);
            assigned++;
            continue;
          }
          if (fs.name()->equals("constantPoolHolderOffset")) {
            set_int("constantPoolHolderOffset", offset_of(ConstantPool, _pool_holder));
            assigned++;
            continue;
          }
          if (fs.name()->equals("klassModifierFlagsOffset")) {
            set_int("klassModifierFlagsOffset", offset_of(Klass, _modifier_flags));
            assigned++;
            continue;
          }
          if (fs.name()->equals("dataLayoutCounterDataTag")) {
            set_int("dataLayoutCounterDataTag", DataLayout::counter_data_tag);
            assigned++;
            continue;
          }
          continue;
        case 25:
          if (fs.name()->equals("instanceKlassFieldsOffset")) {
            set_int("instanceKlassFieldsOffset", offset_of(InstanceKlass, _fields));
            assigned++;
            continue;
          }
          if (fs.name()->equals("deoptimizationDebugIdBits")) {
            set_int("deoptimizationDebugIdBits", Deoptimization::_debug_id_bits);
            assigned++;
            continue;
          }
          if (fs.name()->equals("deoptimizationUnpackDeopt")) {
            set_int("deoptimizationUnpackDeopt", Deoptimization::Unpack_deopt);
            assigned++;
            continue;
          }
          if (fs.name()->equals("jvmAccHasMonitorBytecodes")) {
            set_int("jvmAccHasMonitorBytecodes", JVM_ACC_HAS_MONITOR_BYTECODES);
            assigned++;
            continue;
          }
          if (fs.name()->equals("methodCompiledEntryOffset")) {
            set_int("methodCompiledEntryOffset", offset_of(Method, _from_compiled_entry));
            assigned++;
            continue;
          }
          if (fs.name()->equals("deoptActionMaybeRecompile")) {
            set_int("deoptActionMaybeRecompile", Deoptimization::Action_maybe_recompile);
            assigned++;
            continue;
          }
          if (fs.name()->equals("MARKID_CARD_TABLE_ADDRESS")) {
            set_int("MARKID_CARD_TABLE_ADDRESS", CodeInstaller::CARD_TABLE_ADDRESS);
            assigned++;
            continue;
          }
          if (fs.name()->equals("fieldInfoHighPackedOffset")) {
            set_int("fieldInfoHighPackedOffset", FieldInfo::high_packed_offset);
            assigned++;
            continue;
          }
          if (fs.name()->equals("constMethodCodeSizeOffset")) {
            set_int("constMethodCodeSizeOffset", offset_of(ConstMethod, _code_size));
            assigned++;
            continue;
          }
          if (fs.name()->equals("deoptActionMakeNotEntrant")) {
            set_int("deoptActionMakeNotEntrant", Deoptimization::Action_make_not_entrant);
            assigned++;
            continue;
          }
          if (fs.name()->equals("osThreadInterruptedOffset")) {
            set_int("osThreadInterruptedOffset", offset_of(OSThread, _interrupted));
            assigned++;
            continue;
          }
          if (fs.name()->equals("deoptReasonLoopLimitCheck")) {
            set_int("deoptReasonLoopLimitCheck", Deoptimization::Reason_loop_limit_check);
            assigned++;
            continue;
          }
          if (fs.name()->equals("secondarySuperCacheOffset")) {
            set_int("secondarySuperCacheOffset", offset_of(Klass, _secondary_super_cache));
            assigned++;
            continue;
          }
          if (fs.name()->equals("deoptimizationReasonShift")) {
            set_int("deoptimizationReasonShift", Deoptimization::_reason_shift);
            assigned++;
            continue;
          }
          if (fs.name()->equals("dataLayoutCallTypeDataTag")) {
            set_int("dataLayoutCallTypeDataTag", DataLayout::call_type_data_tag);
            assigned++;
            continue;
          }
          if (fs.name()->equals("deoptimizationActionShift")) {
            set_int("deoptimizationActionShift", Deoptimization::_action_shift);
            assigned++;
            continue;
          }
          if (fs.name()->equals("jvmciCountersThreadOffset")) {
            set_int("jvmciCountersThreadOffset", in_bytes(JavaThread::jvmci_counters_offset()));
            assigned++;
            continue;
          }
          if (fs.name()->equals("layoutHelperArrayTagShift")) {
            set_int("layoutHelperArrayTagShift", Klass::_lh_array_tag_shift);
            assigned++;
            continue;
          }
          if (fs.name()->equals("exceptionTableElementSize")) {
            set_int("exceptionTableElementSize", sizeof(ExceptionTableElement));
            assigned++;
            continue;
          }
          if (fs.name()->equals("barrierSetG1SATBCTLogging")) {
            set_int("barrierSetG1SATBCTLogging", BarrierSet::G1SATBCTLogging);
            assigned++;
            continue;
          }
          if (fs.name()->equals("constMethodMaxStackOffset")) {
            set_int("constMethodMaxStackOffset", offset_of(ConstMethod, _max_stack));
            assigned++;
            continue;
          }
          if (fs.name()->equals("barrierSetCardTableModRef")) {
            set_int("barrierSetCardTableModRef", BarrierSet::CardTableModRef);
            assigned++;
            continue;
          }
          continue;
        case 26:
          if (fs.name()->equals("fieldInfoAccessFlagsOffset")) {
            set_int("fieldInfoAccessFlagsOffset", FieldInfo::access_flags_offset);
            assigned++;
            continue;
          }
          if (fs.name()->equals("methodFlagsCallerSensitive")) {
            set_int("methodFlagsCallerSensitive", Method::_caller_sensitive);
            assigned++;
            continue;
          }
          if (fs.name()->equals("metaspaceArrayLengthOffset")) {
            set_int("metaspaceArrayLengthOffset", offset_of(Array<Klass*>, _length));
            assigned++;
            continue;
          }
          if (fs.name()->equals("threadAllocatedBytesOffset")) {
            set_int("threadAllocatedBytesOffset", offset_of(Thread, _allocated_bytes));
            assigned++;
            continue;
          }
          if (fs.name()->equals("codeInstallResultCacheFull")) {
            set_int("codeInstallResultCacheFull", JVMCIEnv::cache_full);
            assigned++;
            continue;
          }
          if (fs.name()->equals("deoptimizationDebugIdShift")) {
            set_int("deoptimizationDebugIdShift", Deoptimization::_debug_id_shift);
            assigned++;
            continue;
          }
          if (fs.name()->equals("layoutHelperHeaderSizeMask")) {
            set_int("layoutHelperHeaderSizeMask", Klass::_lh_header_size_mask);
            assigned++;
            continue;
          }
          if (fs.name()->equals("cardTableModRefBSCardShift")) {
            set_int("cardTableModRefBSCardShift", CardTableModRefBS::card_shift);
            assigned++;
            continue;
          }
          if (fs.name()->equals("jvmConstantUnresolvedClass")) {
            set_int("jvmConstantUnresolvedClass", JVM_CONSTANT_UnresolvedClass);
            assigned++;
            continue;
          }
          if (fs.name()->equals("javaFrameAnchorFlagsOffset")) {
#if defined(SPARC)
            set_int("javaFrameAnchorFlagsOffset", offset_of(JavaFrameAnchor, _flags));
            assigned++;
#endif
            continue;
          }
          if (fs.name()->equals("MARKID_DEOPT_HANDLER_ENTRY")) {
            set_int("MARKID_DEOPT_HANDLER_ENTRY", CodeInstaller::DEOPT_HANDLER_ENTRY);
            assigned++;
            continue;
          }
          if (fs.name()->equals("constMethodConstantsOffset")) {
            set_int("constMethodConstantsOffset", offset_of(ConstMethod, _constants));
            assigned++;
            continue;
          }
          if (fs.name()->equals("constMethodNameIndexOffset")) {
            set_int("constMethodNameIndexOffset", offset_of(ConstMethod, _name_index));
            assigned++;
            continue;
          }
          if (fs.name()->equals("vmIntrinsicLinkToInterface")) {
            set_int("vmIntrinsicLinkToInterface", vmIntrinsics::_linkToInterface);
            assigned++;
            continue;
          }
          continue;
        case 27:
          if (fs.name()->equals("pendingDeoptimizationOffset")) {
            set_int("pendingDeoptimizationOffset", offset_of(ThreadShadow, _pending_deoptimization));
            assigned++;
            continue;
          }
          if (fs.name()->equals("fieldInfoInitvalIndexOffset")) {
            set_int("fieldInfoInitvalIndexOffset", FieldInfo::initval_index_offset);
            assigned++;
            continue;
          }
          if (fs.name()->equals("layoutHelperElementTypeMask")) {
            set_int("layoutHelperElementTypeMask", Klass::_lh_element_type_mask);
            assigned++;
            continue;
          }
          if (fs.name()->equals("layoutHelperHeaderSizeShift")) {
            set_int("layoutHelperHeaderSizeShift", Klass::_lh_header_size_shift);
            assigned++;
            continue;
          }
          if (fs.name()->equals("constantPoolCpCacheIndexTag")) {
            set_int("constantPoolCpCacheIndexTag", ConstantPool::CPCACHE_INDEX_TAG);
            assigned++;
            continue;
          }
          continue;
        case 28:
          if (fs.name()->equals("deoptActionMakeNotCompilable")) {
            set_int("deoptActionMakeNotCompilable", Deoptimization::Action_make_not_compilable);
            assigned++;
            continue;
          }
          if (fs.name()->equals("instanceKlassConstantsOffset")) {
            set_int("instanceKlassConstantsOffset", offset_of(InstanceKlass, _constants));
            assigned++;
            continue;
          }
          if (fs.name()->equals("deoptReasonTypeCheckInlining")) {
            set_int("deoptReasonTypeCheckInlining", Deoptimization::Reason_type_checked_inlining);
            assigned++;
            continue;
          }
          if (fs.name()->equals("jvmConstantMethodTypeInError")) {
            set_int("jvmConstantMethodTypeInError", JVM_CONSTANT_MethodTypeInError);
            assigned++;
            continue;
          }
          if (fs.name()->equals("layoutHelperElementTypeShift")) {
            set_int("layoutHelperElementTypeShift", Klass::_lh_element_type_shift);
            assigned++;
            continue;
          }
          if (fs.name()->equals("dataLayoutVirtualCallDataTag")) {
            set_int("dataLayoutVirtualCallDataTag", DataLayout::virtual_call_data_tag);
            assigned++;
            continue;
          }
          if (fs.name()->equals("instanceKlassInitStateOffset")) {
            set_int("instanceKlassInitStateOffset", offset_of(InstanceKlass, _init_state));
            assigned++;
            continue;
          }
          if (fs.name()->equals("dataLayoutMultiBranchDataTag")) {
            set_int("dataLayoutMultiBranchDataTag", DataLayout::multi_branch_data_tag);
            assigned++;
            continue;
          }
          if (fs.name()->equals("barrierSetCardTableExtension")) {
            set_int("barrierSetCardTableExtension", BarrierSet::CardTableExtension);
            assigned++;
            continue;
          }
          if (fs.name()->equals("constMethodHasExceptionTable")) {
            set_int("constMethodHasExceptionTable", ConstMethod::_has_exception_table);
            assigned++;
            continue;
          }
          continue;
        case 29:
          if (fs.name()->equals("deoptimizationUnpackReexecute")) {
            set_int("deoptimizationUnpackReexecute", Deoptimization::Unpack_reexecute);
            assigned++;
            continue;
          }
          if (fs.name()->equals("layoutHelperArrayTagTypeValue")) {
            set_int("layoutHelperArrayTagTypeValue", Klass::_lh_array_tag_type_value);
            assigned++;
            continue;
          }
          if (fs.name()->equals("fieldInfoSignatureIndexOffset")) {
            set_int("fieldInfoSignatureIndexOffset", FieldInfo::signature_index_offset);
            assigned++;
            continue;
          }
          if (fs.name()->equals("codeInstallResultCodeTooLarge")) {
            set_int("codeInstallResultCodeTooLarge", JVMCIEnv::code_too_large);
            assigned++;
            continue;
          }
          if (fs.name()->equals("constMethodHasLineNumberTable")) {
            set_int("constMethodHasLineNumberTable", ConstMethod::_has_linenumber_table);
            assigned++;
            continue;
          }
          if (fs.name()->equals("localVariableTableElementSize")) {
            set_int("localVariableTableElementSize", sizeof(LocalVariableTableElement));
            assigned++;
            continue;
          }
          if (fs.name()->equals("dataLayoutReceiverTypeDataTag")) {
            set_int("dataLayoutReceiverTypeDataTag", DataLayout::receiver_type_data_tag);
            assigned++;
            continue;
          }
          if (fs.name()->equals("deoptReasonOptimizedTypeCheck")) {
            set_int("deoptReasonOptimizedTypeCheck", Deoptimization::Reason_optimized_type_check);
            assigned++;
            continue;
          }
          if (fs.name()->equals("deoptimizationUnpackException")) {
            set_int("deoptimizationUnpackException", Deoptimization::Unpack_exception);
            assigned++;
            continue;
          }
          if (fs.name()->equals("virtualSpaceLowBoundaryOffset")) {
            set_int("virtualSpaceLowBoundaryOffset", offset_of(VirtualSpace, _low_boundary));
            assigned++;
            continue;
          }
          if (fs.name()->equals("jvmConstantInterfaceMethodref")) {
            set_int("jvmConstantInterfaceMethodref", JVM_CONSTANT_InterfaceMethodref);
            assigned++;
            continue;
          }
          if (fs.name()->equals("collectedHeapBarrierSetOffset")) {
            set_int("collectedHeapBarrierSetOffset", offset_of(CollectedHeap, _barrier_set));
            assigned++;
            continue;
          }
          if (fs.name()->equals("allocateInstancePrefetchLines")) {
            set_int("allocateInstancePrefetchLines", AllocateInstancePrefetchLines);
            assigned++;
            continue;
          }
          if (fs.name()->equals("klassLayoutHelperNeutralValue")) {
            set_int("klassLayoutHelperNeutralValue", Klass::_lh_neutral_value);
            assigned++;
            continue;
          }
          if (fs.name()->equals("javaThreadSatbMarkQueueOffset")) {
            set_int("javaThreadSatbMarkQueueOffset", offset_of(JavaThread, _satb_mark_queue));
            assigned++;
            continue;
          }
          continue;
        case 30:
          if (fs.name()->equals("jvmAccFieldHasGenericSignature")) {
            set_int("jvmAccFieldHasGenericSignature", JVM_ACC_FIELD_HAS_GENERIC_SIGNATURE);
            assigned++;
            continue;
          }
          if (fs.name()->equals("MARKID_EXCEPTION_HANDLER_ENTRY")) {
            set_int("MARKID_EXCEPTION_HANDLER_ENTRY", CodeInstaller::EXCEPTION_HANDLER_ENTRY);
            assigned++;
            continue;
          }
          if (fs.name()->equals("virtualSpaceHighBoundaryOffset")) {
            set_int("virtualSpaceHighBoundaryOffset", offset_of(VirtualSpace, _high_boundary));
            assigned++;
            continue;
          }
          if (fs.name()->equals("jvmConstantMethodHandleInError")) {
            set_int("jvmConstantMethodHandleInError", JVM_CONSTANT_MethodHandleInError);
            assigned++;
            continue;
          }
          if (fs.name()->equals("instanceKlassVtableStartOffset")) {
            set_int("instanceKlassVtableStartOffset", InstanceKlass::vtable_start_offset() * HeapWordSize);
            assigned++;
            continue;
          }
          if (fs.name()->equals("methodDataOopTrapHistoryOffset")) {
            set_int("methodDataOopTrapHistoryOffset", offset_of(MethodData, _trap_hist._array[0]));
            assigned++;
            continue;
          }
          if (fs.name()->equals("javaThreadDirtyCardQueueOffset")) {
            set_int("javaThreadDirtyCardQueueOffset", offset_of(JavaThread, _dirty_card_queue));
            assigned++;
            continue;
          }
          if (fs.name()->equals("basicLockDisplacedHeaderOffset")) {
            set_int("basicLockDisplacedHeaderOffset", offset_of(BasicLock, _displaced_header));
            assigned++;
            continue;
          }
          if (fs.name()->equals("pendingFailedSpeculationOffset")) {
            set_int("pendingFailedSpeculationOffset", offset_of(ThreadShadow, _pending_failed_speculation));
            assigned++;
            continue;
          }
          continue;
        case 31:
          if (fs.name()->equals("dataLayoutParametersTypeDataTag")) {
            set_int("dataLayoutParametersTypeDataTag", DataLayout::parameters_type_data_tag);
            assigned++;
            continue;
          }
          if (fs.name()->equals("javaFrameAnchorLastJavaPcOffset")) {
            set_int("javaFrameAnchorLastJavaPcOffset", offset_of(JavaFrameAnchor, _last_Java_pc));
            assigned++;
            continue;
          }
          if (fs.name()->equals("threadLocalAllocBufferTopOffset")) {
            set_int("threadLocalAllocBufferTopOffset", offset_of(ThreadLocalAllocBuffer, _top));
            assigned++;
            continue;
          }
          if (fs.name()->equals("layoutHelperLog2ElementSizeMask")) {
            set_int("layoutHelperLog2ElementSizeMask", Klass::_lh_log2_element_size_mask);
            assigned++;
            continue;
          }
          if (fs.name()->equals("javaFrameAnchorLastJavaFpOffset")) {
#if defined(AMD64)
            set_int("javaFrameAnchorLastJavaFpOffset", offset_of(JavaFrameAnchor, _last_Java_fp));
            assigned++;
#endif
            continue;
          }
          if (fs.name()->equals("instanceKlassVtableLengthOffset")) {
            set_int("instanceKlassVtableLengthOffset", InstanceKlass::vtable_length_offset() * HeapWordSize);
            assigned++;
            continue;
          }
          if (fs.name()->equals("layoutHelperArrayTagObjectValue")) {
            set_int("layoutHelperArrayTagObjectValue", Klass::_lh_array_tag_obj_value);
            assigned++;
            continue;
          }
          if (fs.name()->equals("threadLocalAllocBufferEndOffset")) {
            set_int("threadLocalAllocBufferEndOffset", offset_of(ThreadLocalAllocBuffer, _end));
            assigned++;
            continue;
          }
          if (fs.name()->equals("javaFrameAnchorLastJavaSpOffset")) {
            set_int("javaFrameAnchorLastJavaSpOffset", offset_of(JavaFrameAnchor, _last_Java_sp));
            assigned++;
            continue;
          }
          if (fs.name()->equals("constMethodSignatureIndexOffset")) {
            set_int("constMethodSignatureIndexOffset", offset_of(ConstMethod, _signature_index));
            assigned++;
            continue;
          }
          if (fs.name()->equals("arrayKlassComponentMirrorOffset")) {
            set_int("arrayKlassComponentMirrorOffset", offset_of(ArrayKlass, _component_mirror));
            assigned++;
            continue;
          }
          continue;
        case 32:
          if (fs.name()->equals("constMethodHasLocalVariableTable")) {
            set_int("constMethodHasLocalVariableTable", ConstMethod::_has_localvariable_table);
            assigned++;
            continue;
          }
          if (fs.name()->equals("exceptionTableElementEndPcOffset")) {
            set_int("exceptionTableElementEndPcOffset", offset_of(ExceptionTableElement, end_pc));
            assigned++;
            continue;
          }
          if (fs.name()->equals("layoutHelperLog2ElementSizeShift")) {
            set_int("layoutHelperLog2ElementSizeShift", Klass::_lh_log2_element_size_shift);
            assigned++;
            continue;
          }
          if (fs.name()->equals("threadIsMethodHandleReturnOffset")) {
            set_int("threadIsMethodHandleReturnOffset", offset_of(JavaThread, _is_method_handle_return));
            assigned++;
            continue;
          }
          if (fs.name()->equals("dataLayoutSpeculativeTrapDataTag")) {
            set_int("dataLayoutSpeculativeTrapDataTag", DataLayout::speculative_trap_data_tag);
            assigned++;
            continue;
          }
          if (fs.name()->equals("dataLayoutVirtualCallTypeDataTag")) {
            set_int("dataLayoutVirtualCallTypeDataTag", DataLayout::virtual_call_type_data_tag);
            assigned++;
            continue;
          }
          if (fs.name()->equals("compilationLevelFullOptimization")) {
            set_int("compilationLevelFullOptimization", CompLevel_full_optimization);
            assigned++;
            continue;
          }
          if (fs.name()->equals("deoptimizationUnpackUncommonTrap")) {
            set_int("deoptimizationUnpackUncommonTrap", Deoptimization::Unpack_uncommon_trap);
            assigned++;
            continue;
          }
          if (fs.name()->equals("deoptReasonTransferToInterpreter")) {
            set_int("deoptReasonTransferToInterpreter", Deoptimization::Reason_transfer_to_interpreter);
            assigned++;
            continue;
          }
          continue;
        case 33:
          if (fs.name()->equals("threadLocalAllocBufferPfTopOffset")) {
            set_int("threadLocalAllocBufferPfTopOffset", offset_of(ThreadLocalAllocBuffer, _pf_top));
            assigned++;
            continue;
          }
          if (fs.name()->equals("threadLocalAllocBufferStartOffset")) {
            set_int("threadLocalAllocBufferStartOffset", offset_of(ThreadLocalAllocBuffer, _start));
            assigned++;
            continue;
          }
          if (fs.name()->equals("jvmConstantUnresolvedClassInError")) {
            set_int("jvmConstantUnresolvedClassInError", JVM_CONSTANT_UnresolvedClassInError);
            assigned++;
            continue;
          }
          if (fs.name()->equals("frameInterpreterFrameLastSpOffset")) {
#if defined(AMD64)
            set_int("frameInterpreterFrameLastSpOffset", frame::interpreter_frame_last_sp_offset);
            assigned++;
#endif
            continue;
          }
          continue;
        case 34:
          if (fs.name()->equals("pendingTransferToInterpreterOffset")) {
            set_int("pendingTransferToInterpreterOffset", offset_of(ThreadShadow, _pending_transfer_to_interpreter));
            assigned++;
            continue;
          }
          if (fs.name()->equals("instanceKlassStateFullyInitialized")) {
            set_int("instanceKlassStateFullyInitialized", InstanceKlass::fully_initialized);
            assigned++;
            continue;
          }
          if (fs.name()->equals("cardTableModRefBSByteMapBaseOffset")) {
            set_int("cardTableModRefBSByteMapBaseOffset", offset_of(CardTableModRefBS, byte_map_base));
            assigned++;
            continue;
          }
          if (fs.name()->equals("uninitializedIdentityHashCodeValue")) {
            set_int("uninitializedIdentityHashCodeValue", markOopDesc::no_hash);
            assigned++;
            continue;
          }
          if (fs.name()->equals("exceptionTableElementStartPcOffset")) {
            set_int("exceptionTableElementStartPcOffset", offset_of(ExceptionTableElement, start_pc));
            assigned++;
            continue;
          }
          continue;
        case 35:
          if (fs.name()->equals("collectedHeapTotalCollectionsOffset")) {
            set_int("collectedHeapTotalCollectionsOffset", offset_of(CollectedHeap, _total_collections));
            assigned++;
            continue;
          }
          if (fs.name()->equals("frameInterpreterFrameSenderSpOffset")) {
#if defined(AMD64)
            set_int("frameInterpreterFrameSenderSpOffset", frame::interpreter_frame_sender_sp_offset);
            assigned++;
#endif
            continue;
          }
          if (fs.name()->equals("localVariableTableElementSlotOffset")) {
            set_int("localVariableTableElementSlotOffset", offset_of(LocalVariableTableElement, slot));
            assigned++;
            continue;
          }
          if (fs.name()->equals("codeInstallResultDependenciesFailed")) {
            set_int("codeInstallResultDependenciesFailed", JVMCIEnv::dependencies_failed);
            assigned++;
            continue;
          }
          continue;
        case 36:
          if (fs.name()->equals("compileTaskNumInlinedBytecodesOffset")) {
            set_int("compileTaskNumInlinedBytecodesOffset", offset_of(CompileTask, _num_inlined_bytecodes));
            assigned++;
            continue;
          }
          if (fs.name()->equals("exceptionTableElementHandlerPcOffset")) {
            set_int("exceptionTableElementHandlerPcOffset", offset_of(ExceptionTableElement, handler_pc));
            assigned++;
            continue;
          }
          if (fs.name()->equals("klassLayoutHelperInstanceSlowPathBit")) {
            set_int("klassLayoutHelperInstanceSlowPathBit", Klass::_lh_instance_slow_path_bit);
            assigned++;
            continue;
          }
          if (fs.name()->equals("codeInstallResultDependenciesInvalid")) {
            set_int("codeInstallResultDependenciesInvalid", JVMCIEnv::dependencies_invalid);
            assigned++;
            continue;
          }
          continue;
        case 37:
          if (fs.name()->equals("localVariableTableElementLengthOffset")) {
            set_int("localVariableTableElementLengthOffset", offset_of(LocalVariableTableElement, length));
            assigned++;
            continue;
          }
          continue;
        case 38:
          if (fs.name()->equals("instanceKlassSourceFileNameIndexOffset")) {
            set_int("instanceKlassSourceFileNameIndexOffset", offset_of(InstanceKlass, _source_file_name_index));
            assigned++;
            continue;
          }
          if (fs.name()->equals("deoptReasonNotCompiledExceptionHandler")) {
            set_int("deoptReasonNotCompiledExceptionHandler", Deoptimization::Reason_not_compiled_exception_handler);
            assigned++;
            continue;
          }
          continue;
        case 39:
          if (fs.name()->equals("localVariableTableElementStartBciOffset")) {
            set_int("localVariableTableElementStartBciOffset", offset_of(LocalVariableTableElement, start_bci));
            assigned++;
            continue;
          }
          if (fs.name()->equals("threadLocalAllocBufferDesiredSizeOffset")) {
            set_int("threadLocalAllocBufferDesiredSizeOffset", offset_of(ThreadLocalAllocBuffer, _desired_size));
            assigned++;
            continue;
          }
          if (fs.name()->equals("deoptimizationUnrollBlockFramePcsOffset")) {
            set_int("deoptimizationUnrollBlockFramePcsOffset", offset_of(Deoptimization::UnrollBlock, _frame_pcs));
            assigned++;
            continue;
          }
          continue;
        case 41:
          if (fs.name()->equals("exceptionTableElementCatchTypeIndexOffset")) {
            set_int("exceptionTableElementCatchTypeIndexOffset", offset_of(ExceptionTableElement, catch_type_index));
            assigned++;
            continue;
          }
          if (fs.name()->equals("deoptimizationUnrollBlockFrameSizesOffset")) {
            set_int("deoptimizationUnrollBlockFrameSizesOffset", offset_of(Deoptimization::UnrollBlock, _frame_sizes));
            assigned++;
            continue;
          }
          continue;
        case 42:
          if (fs.name()->equals("deoptimizationUnrollBlockInitialInfoOffset")) {
            set_int("deoptimizationUnrollBlockInitialInfoOffset", offset_of(Deoptimization::UnrollBlock, _initial_info));
            assigned++;
            continue;
          }
          if (fs.name()->equals("localVariableTableElementNameCpIndexOffset")) {
            set_int("localVariableTableElementNameCpIndexOffset", offset_of(LocalVariableTableElement, name_cp_index));
            assigned++;
            continue;
          }
          continue;
        case 43:
          if (fs.name()->equals("threadLocalAllocBufferNumberOfRefillsOffset")) {
            set_int("threadLocalAllocBufferNumberOfRefillsOffset", offset_of(ThreadLocalAllocBuffer, _number_of_refills));
            assigned++;
            continue;
          }
          if (fs.name()->equals("threadLocalAllocBufferSlowAllocationsOffset")) {
            set_int("threadLocalAllocBufferSlowAllocationsOffset", offset_of(ThreadLocalAllocBuffer, _slow_allocations));
            assigned++;
            continue;
          }
          if (fs.name()->equals("threadLocalAllocBufferFastRefillWasteOffset")) {
            set_int("threadLocalAllocBufferFastRefillWasteOffset", offset_of(ThreadLocalAllocBuffer, _fast_refill_waste));
            assigned++;
            continue;
          }
          continue;
        case 44:
          if (fs.name()->equals("threadLocalAllocBufferRefillWasteLimitOffset")) {
            set_int("threadLocalAllocBufferRefillWasteLimitOffset", offset_of(ThreadLocalAllocBuffer, _refill_waste_limit));
            assigned++;
            continue;
          }
          continue;
        case 45:
          if (fs.name()->equals("deoptimizationUnrollBlockNumberOfFramesOffset")) {
            set_int("deoptimizationUnrollBlockNumberOfFramesOffset", offset_of(Deoptimization::UnrollBlock, _number_of_frames));
            assigned++;
            continue;
          }
          if (fs.name()->equals("jvmciEnvJvmtiCanHotswapOrPostBreakpointOffset")) {
            set_int("jvmciEnvJvmtiCanHotswapOrPostBreakpointOffset", offset_of(JVMCIEnv, _jvmti_can_hotswap_or_post_breakpoint));
            assigned++;
            continue;
          }
          continue;
        case 46:
          if (fs.name()->equals("deoptimizationUnrollBlockTotalFrameSizesOffset")) {
            set_int("deoptimizationUnrollBlockTotalFrameSizesOffset", offset_of(Deoptimization::UnrollBlock, _total_frame_sizes));
            assigned++;
            continue;
          }
          continue;
        case 47:
          if (fs.name()->equals("deoptimizationUnrollBlockCallerAdjustmentOffset")) {
            set_int("deoptimizationUnrollBlockCallerAdjustmentOffset", offset_of(Deoptimization::UnrollBlock, _caller_adjustment));
            assigned++;
            continue;
          }
          if (fs.name()->equals("localVariableTableElementSignatureCpIndexOffset")) {
            set_int("localVariableTableElementSignatureCpIndexOffset", offset_of(LocalVariableTableElement, signature_cp_index));
            assigned++;
            continue;
          }
          continue;
        case 48:
          if (fs.name()->equals("localVariableTableElementDescriptorCpIndexOffset")) {
            set_int("localVariableTableElementDescriptorCpIndexOffset", offset_of(LocalVariableTableElement, descriptor_cp_index));
            assigned++;
            continue;
          }
          continue;
        case 53:
          if (fs.name()->equals("deoptimizationUnrollBlockSizeOfDeoptimizedFrameOffset")) {
            set_int("deoptimizationUnrollBlockSizeOfDeoptimizedFrameOffset", offset_of(Deoptimization::UnrollBlock, _size_of_deoptimized_frame));
            assigned++;
            continue;
          }
          continue;
      } // switch
      continue;
    } // if
    if (fs.signature() == vmSymbols::long_signature()) {
      switch (fs.name()->utf8_length()) {
        case 7:
          if (fs.name()->equals("dllLoad")) {
            set_address("dllLoad", os::dll_load);
            assigned++;
            continue;
          }
          continue;
        case 9:
          if (fs.name()->equals("dllLookup")) {
            set_address("dllLookup", os::dll_lookup);
            assigned++;
            continue;
          }
          continue;
        case 10:
          if (fs.name()->equals("nonOopBits")) {
            set_long("nonOopBits", (long) (intptr_t) Universe::_non_oop_bits);
            assigned++;
            continue;
          }
          continue;
        case 11:
          if (fs.name()->equals("rtldDefault")) {
#if defined(TARGET_OS_FAMILY_bsd) || defined(TARGET_OS_FAMILY_linux)
            set_address("rtldDefault", RTLD_DEFAULT);
            assigned++;
#endif
            continue;
          }
          continue;
        case 12:
          if (fs.name()->equals("oopArraycopy")) {
            set_long("oopArraycopy", (long) (intptr_t) StubRoutines::_oop_arraycopy);
            assigned++;
            continue;
          }
          continue;
        case 13:
          if (fs.name()->equals("verifyOopBits")) {
            set_long("verifyOopBits", Universe::verify_oop_bits());
            assigned++;
            continue;
          }
          if (fs.name()->equals("verifyOopMask")) {
            set_long("verifyOopMask", Universe::verify_oop_mask());
            assigned++;
            continue;
          }
          if (fs.name()->equals("codeCacheHeap")) {
            set_long("codeCacheHeap", (long) (intptr_t) CodeCache::_heap);
            assigned++;
            continue;
          }
          if (fs.name()->equals("jintArraycopy")) {
            set_long("jintArraycopy", (long) (intptr_t) StubRoutines::_jint_arraycopy);
            assigned++;
            continue;
          }
          if (fs.name()->equals("narrowOopBase")) {
            set_long("narrowOopBase", (long) (intptr_t) Universe::_narrow_oop._base);
            assigned++;
            continue;
          }
          continue;
        case 14:
          if (fs.name()->equals("heapTopAddress")) {
            set_address("heapTopAddress", Universe::heap()->supports_inline_contig_alloc() ? Universe::heap()->top_addr() : (HeapWord**)-1);
            assigned++;
            continue;
          }
          if (fs.name()->equals("jbyteArraycopy")) {
            set_long("jbyteArraycopy", (long) (intptr_t) StubRoutines::_jbyte_arraycopy);
            assigned++;
            continue;
          }
          if (fs.name()->equals("vmErrorAddress")) {
            set_address("vmErrorAddress", JVMCIRuntime::vm_error);
            assigned++;
            continue;
          }
          if (fs.name()->equals("validateObject")) {
            set_address("validateObject", JVMCIRuntime::validate_object);
            assigned++;
            continue;
          }
          if (fs.name()->equals("jlongArraycopy")) {
            set_long("jlongArraycopy", (long) (intptr_t) StubRoutines::_jlong_arraycopy);
            assigned++;
            continue;
          }
          if (fs.name()->equals("heapEndAddress")) {
            set_address("heapEndAddress", Universe::heap()->supports_inline_contig_alloc() ? Universe::heap()->end_addr() : (HeapWord**)-1);
            assigned++;
            continue;
          }
          continue;
        case 15:
          if (fs.name()->equals("narrowKlassBase")) {
            set_long("narrowKlassBase", (long) (intptr_t) Universe::_narrow_klass._base);
            assigned++;
            continue;
          }
          if (fs.name()->equals("newArrayAddress")) {
            set_address("newArrayAddress", JVMCIRuntime::new_array);
            assigned++;
            continue;
          }
          if (fs.name()->equals("handleDeoptStub")) {
            set_address("handleDeoptStub", SharedRuntime::deopt_blob()->unpack());
            assigned++;
            continue;
          }
          if (fs.name()->equals("crcTableAddress")) {
            set_long("crcTableAddress", (long) (intptr_t) StubRoutines::_crc_table_adr);
            assigned++;
            continue;
          }
          if (fs.name()->equals("unsafeArraycopy")) {
            set_long("unsafeArraycopy", (long) (intptr_t) StubRoutines::_unsafe_arraycopy);
            assigned++;
            continue;
          }
          if (fs.name()->equals("gHotSpotVMTypes")) {
            set_address("gHotSpotVMTypes", gHotSpotVMTypes);
            assigned++;
            continue;
          }
          if (fs.name()->equals("jshortArraycopy")) {
            set_long("jshortArraycopy", (long) (intptr_t) StubRoutines::_jshort_arraycopy);
            assigned++;
            continue;
          }
          continue;
        case 16:
          if (fs.name()->equals("vmSymbolsSymbols")) {
            set_address("vmSymbolsSymbols", &vmSymbols::_symbols[0]);
            assigned++;
            continue;
          }
          if (fs.name()->equals("logObjectAddress")) {
            set_address("logObjectAddress", JVMCIRuntime::log_object);
            assigned++;
            continue;
          }
          if (fs.name()->equals("logPrintfAddress")) {
            set_address("logPrintfAddress", JVMCIRuntime::log_printf);
            assigned++;
            continue;
          }
          if (fs.name()->equals("vmMessageAddress")) {
            set_address("vmMessageAddress", JVMCIRuntime::vm_message);
            assigned++;
            continue;
          }
          if (fs.name()->equals("uncommonTrapStub")) {
            set_address("uncommonTrapStub", SharedRuntime::deopt_blob()->uncommon_trap());
            assigned++;
            continue;
          }
          if (fs.name()->equals("genericArraycopy")) {
            set_long("genericArraycopy", (long) (intptr_t) StubRoutines::_generic_arraycopy);
            assigned++;
            continue;
          }
          continue;
        case 17:
          if (fs.name()->equals("gHotSpotVMStructs")) {
            set_address("gHotSpotVMStructs", gHotSpotVMStructs);
            assigned++;
            continue;
          }
          continue;
        case 18:
          if (fs.name()->equals("checkcastArraycopy")) {
            set_long("checkcastArraycopy", (long) (intptr_t) StubRoutines::_checkcast_arraycopy);
            assigned++;
            continue;
          }
          if (fs.name()->equals("newInstanceAddress")) {
            set_address("newInstanceAddress", JVMCIRuntime::new_instance);
            assigned++;
            continue;
          }
          if (fs.name()->equals("monitorexitAddress")) {
            set_address("monitorexitAddress", JVMCIRuntime::monitorexit);
            assigned++;
            continue;
          }
          if (fs.name()->equals("oopArraycopyUninit")) {
            set_long("oopArraycopyUninit", (long) (intptr_t) StubRoutines::_oop_arraycopy_uninit);
            assigned++;
            continue;
          }
          continue;
        case 19:
          if (fs.name()->equals("monitorenterAddress")) {
            set_address("monitorenterAddress", JVMCIRuntime::monitorenter);
            assigned++;
            continue;
          }
          if (fs.name()->equals("inlineCacheMissBlob")) {
            set_long("inlineCacheMissBlob", (long) (intptr_t) SharedRuntime::_ic_miss_blob);
            assigned++;
            continue;
          }
          if (fs.name()->equals("logPrimitiveAddress")) {
            set_address("logPrimitiveAddress", JVMCIRuntime::log_primitive);
            assigned++;
            continue;
          }
          if (fs.name()->equals("oopAlignedArraycopy")) {
            set_long("oopAlignedArraycopy", (long) (intptr_t) StubRoutines::_arrayof_oop_arraycopy);
            assigned++;
            continue;
          }
          if (fs.name()->equals("markOopDescHashMask")) {
            set_long("markOopDescHashMask", markOopDesc::hash_mask);
            assigned++;
            continue;
          }
          continue;
        case 20:
          if (fs.name()->equals("jintAlignedArraycopy")) {
            set_long("jintAlignedArraycopy", (long) (intptr_t) StubRoutines::_arrayof_jint_arraycopy);
            assigned++;
            continue;
          }
          if (fs.name()->equals("markOopDescHashShift")) {
            set_long("markOopDescHashShift", markOopDesc::hash_shift);
            assigned++;
            continue;
          }
          if (fs.name()->equals("updateBytesCRC32Stub")) {
            set_long("updateBytesCRC32Stub", (long) (intptr_t) StubRoutines::_updateBytesCRC32);
            assigned++;
            continue;
          }
          if (fs.name()->equals("arithmeticTanAddress")) {
            set_address("arithmeticTanAddress", SharedRuntime::dtan);
            assigned++;
            continue;
          }
          if (fs.name()->equals("arithmeticExpAddress")) {
            set_address("arithmeticExpAddress", SharedRuntime::dexp);
            assigned++;
            continue;
          }
          if (fs.name()->equals("arithmeticSinAddress")) {
            set_address("arithmeticSinAddress", SharedRuntime::dsin);
            assigned++;
            continue;
          }
          if (fs.name()->equals("arithmeticCosAddress")) {
            set_address("arithmeticCosAddress", SharedRuntime::dcos);
            assigned++;
            continue;
          }
          if (fs.name()->equals("newMultiArrayAddress")) {
            set_address("newMultiArrayAddress", JVMCIRuntime::new_multi_array);
            assigned++;
            continue;
          }
          if (fs.name()->equals("oopDisjointArraycopy")) {
            set_long("oopDisjointArraycopy", (long) (intptr_t) StubRoutines::_oop_disjoint_arraycopy);
            assigned++;
            continue;
          }
          if (fs.name()->equals("arithmeticLogAddress")) {
            set_address("arithmeticLogAddress", SharedRuntime::dlog);
            assigned++;
            continue;
          }
          if (fs.name()->equals("arithmeticPowAddress")) {
            set_address("arithmeticPowAddress", SharedRuntime::dpow);
            assigned++;
            continue;
          }
          if (fs.name()->equals("javaTimeNanosAddress")) {
            set_address("javaTimeNanosAddress", os::javaTimeNanos);
            assigned++;
            continue;
          }
          continue;
        case 21:
          if (fs.name()->equals("universeCollectedHeap")) {
            set_long("universeCollectedHeap", (long) (intptr_t) Universe::_collectedHeap);
            assigned++;
            continue;
          }
          if (fs.name()->equals("jbyteAlignedArraycopy")) {
            set_long("jbyteAlignedArraycopy", (long) (intptr_t) StubRoutines::_arrayof_jbyte_arraycopy);
            assigned++;
            continue;
          }
          if (fs.name()->equals("testDeoptimizeCallInt")) {
            set_address("testDeoptimizeCallInt", JVMCIRuntime::test_deoptimize_call_int);
            assigned++;
            continue;
          }
          if (fs.name()->equals("jlongAlignedArraycopy")) {
            set_long("jlongAlignedArraycopy", (long) (intptr_t) StubRoutines::_arrayof_jlong_arraycopy);
            assigned++;
            continue;
          }
          if (fs.name()->equals("javaTimeMillisAddress")) {
            set_address("javaTimeMillisAddress", os::javaTimeMillis);
            assigned++;
            continue;
          }
          if (fs.name()->equals("jintDisjointArraycopy")) {
            set_long("jintDisjointArraycopy", (long) (intptr_t) StubRoutines::_jint_disjoint_arraycopy);
            assigned++;
            continue;
          }
          continue;
        case 22:
          if (fs.name()->equals("jshortAlignedArraycopy")) {
            set_long("jshortAlignedArraycopy", (long) (intptr_t) StubRoutines::_arrayof_jshort_arraycopy);
            assigned++;
            continue;
          }
          if (fs.name()->equals("jlongDisjointArraycopy")) {
            set_long("jlongDisjointArraycopy", (long) (intptr_t) StubRoutines::_jlong_disjoint_arraycopy);
            assigned++;
            continue;
          }
          if (fs.name()->equals("osrMigrationEndAddress")) {
            set_address("osrMigrationEndAddress", SharedRuntime::OSR_migration_end);
            assigned++;
            continue;
          }
          if (fs.name()->equals("arithmeticLog10Address")) {
            set_address("arithmeticLog10Address", SharedRuntime::dlog10);
            assigned++;
            continue;
          }
          if (fs.name()->equals("gHotSpotVMIntConstants")) {
            set_address("gHotSpotVMIntConstants", gHotSpotVMIntConstants);
            assigned++;
            continue;
          }
          if (fs.name()->equals("dynamicNewArrayAddress")) {
            set_address("dynamicNewArrayAddress", JVMCIRuntime::dynamic_new_array);
            assigned++;
            continue;
          }
          if (fs.name()->equals("writeBarrierPreAddress")) {
            set_address("writeBarrierPreAddress", JVMCIRuntime::write_barrier_pre);
            assigned++;
            continue;
          }
          if (fs.name()->equals("jbyteDisjointArraycopy")) {
            set_long("jbyteDisjointArraycopy", (long) (intptr_t) StubRoutines::_jbyte_disjoint_arraycopy);
            assigned++;
            continue;
          }
          continue;
        case 23:
          if (fs.name()->equals("gHotSpotVMLongConstants")) {
            set_address("gHotSpotVMLongConstants", gHotSpotVMLongConstants);
            assigned++;
            continue;
          }
          if (fs.name()->equals("jshortDisjointArraycopy")) {
            set_long("jshortDisjointArraycopy", (long) (intptr_t) StubRoutines::_jshort_disjoint_arraycopy);
            assigned++;
            continue;
          }
          if (fs.name()->equals("verifyOopCounterAddress")) {
            set_address("verifyOopCounterAddress", &StubRoutines::_verify_oop_count);
            assigned++;
            continue;
          }
          if (fs.name()->equals("identityHashCodeAddress")) {
            set_address("identityHashCodeAddress", JVMCIRuntime::identity_hash_code);
            assigned++;
            continue;
          }
          if (fs.name()->equals("writeBarrierPostAddress")) {
            set_address("writeBarrierPostAddress", JVMCIRuntime::write_barrier_post);
            assigned++;
            continue;
          }
          if (fs.name()->equals("safepointPollingAddress")) {
            set_long("safepointPollingAddress", (long) (intptr_t) os::_polling_page);
            assigned++;
            continue;
          }
          continue;
        case 24:
          if (fs.name()->equals("registerFinalizerAddress")) {
            set_address("registerFinalizerAddress", SharedRuntime::register_finalizer);
            assigned++;
            continue;
          }
          if (fs.name()->equals("aescryptEncryptBlockStub")) {
            set_long("aescryptEncryptBlockStub", (long) (intptr_t) StubRoutines::_aescrypt_encryptBlock);
            assigned++;
            continue;
          }
          if (fs.name()->equals("checkcastArraycopyUninit")) {
            set_long("checkcastArraycopyUninit", (long) (intptr_t) StubRoutines::_checkcast_arraycopy_uninit);
            assigned++;
            continue;
          }
          if (fs.name()->equals("aescryptDecryptBlockStub")) {
            set_long("aescryptDecryptBlockStub", (long) (intptr_t) StubRoutines::_aescrypt_decryptBlock);
            assigned++;
            continue;
          }
          continue;
        case 25:
          if (fs.name()->equals("dynamicNewInstanceAddress")) {
            set_address("dynamicNewInstanceAddress", JVMCIRuntime::dynamic_new_instance);
            assigned++;
            continue;
          }
          if (fs.name()->equals("oopAlignedArraycopyUninit")) {
            set_long("oopAlignedArraycopyUninit", (long) (intptr_t) StubRoutines::_arrayof_oop_arraycopy_uninit);
            assigned++;
            continue;
          }
          continue;
        case 26:
          if (fs.name()->equals("oopDisjointArraycopyUninit")) {
            set_long("oopDisjointArraycopyUninit", (long) (intptr_t) StubRoutines::_oop_disjoint_arraycopy_uninit);
            assigned++;
            continue;
          }
          if (fs.name()->equals("deoptimizationUnpackFrames")) {
            set_address("deoptimizationUnpackFrames", Deoptimization::unpack_frames);
            assigned++;
            continue;
          }
          if (fs.name()->equals("markOopDescHashMaskInPlace")) {
            set_long("markOopDescHashMaskInPlace", markOopDesc::hash_mask_in_place);
            assigned++;
            continue;
          }
          if (fs.name()->equals("deoptimizationUncommonTrap")) {
            set_address("deoptimizationUncommonTrap", Deoptimization::uncommon_trap);
            assigned++;
            continue;
          }
          if (fs.name()->equals("threadIsInterruptedAddress")) {
            set_address("threadIsInterruptedAddress", JVMCIRuntime::thread_is_interrupted);
            assigned++;
            continue;
          }
          continue;
        case 27:
          if (fs.name()->equals("oopAlignedDisjointArraycopy")) {
            set_long("oopAlignedDisjointArraycopy", (long) (intptr_t) StubRoutines::_arrayof_oop_disjoint_arraycopy);
            assigned++;
            continue;
          }
          continue;
        case 28:
          if (fs.name()->equals("loadAndClearExceptionAddress")) {
            set_address("loadAndClearExceptionAddress", JVMCIRuntime::load_and_clear_exception);
            assigned++;
            continue;
          }
          if (fs.name()->equals("exceptionHandlerForPcAddress")) {
            set_address("exceptionHandlerForPcAddress", JVMCIRuntime::exception_handler_for_pc);
            assigned++;
            continue;
          }
          if (fs.name()->equals("jintAlignedDisjointArraycopy")) {
            set_long("jintAlignedDisjointArraycopy", (long) (intptr_t) StubRoutines::_arrayof_jint_disjoint_arraycopy);
            assigned++;
            continue;
          }
          continue;
        case 29:
          if (fs.name()->equals("deoptimizationFetchUnrollInfo")) {
            set_address("deoptimizationFetchUnrollInfo", Deoptimization::fetch_unroll_info);
            assigned++;
            continue;
          }
          if (fs.name()->equals("gHotSpotVMTypeEntrySizeOffset")) {
            set_long("gHotSpotVMTypeEntrySizeOffset", gHotSpotVMTypeEntrySizeOffset);
            assigned++;
            continue;
          }
          if (fs.name()->equals("jbyteAlignedDisjointArraycopy")) {
            set_long("jbyteAlignedDisjointArraycopy", (long) (intptr_t) StubRoutines::_arrayof_jbyte_disjoint_arraycopy);
            assigned++;
            continue;
          }
          if (fs.name()->equals("jlongAlignedDisjointArraycopy")) {
            set_long("jlongAlignedDisjointArraycopy", (long) (intptr_t) StubRoutines::_arrayof_jlong_disjoint_arraycopy);
            assigned++;
            continue;
          }
          continue;
        case 30:
          if (fs.name()->equals("jshortAlignedDisjointArraycopy")) {
            set_long("jshortAlignedDisjointArraycopy", (long) (intptr_t) StubRoutines::_arrayof_jshort_disjoint_arraycopy);
            assigned++;
            continue;
          }
          if (fs.name()->equals("gHotSpotVMTypeEntryArrayStride")) {
            set_long("gHotSpotVMTypeEntryArrayStride", gHotSpotVMTypeEntryArrayStride);
            assigned++;
            continue;
          }
          continue;
        case 32:
          if (fs.name()->equals("gHotSpotVMStructEntryArrayStride")) {
            set_long("gHotSpotVMStructEntryArrayStride", gHotSpotVMStructEntryArrayStride);
            assigned++;
            continue;
          }
          continue;
        case 33:
          if (fs.name()->equals("gHotSpotVMStructEntryOffsetOffset")) {
            set_long("gHotSpotVMStructEntryOffsetOffset", gHotSpotVMStructEntryOffsetOffset);
            assigned++;
            continue;
          }
          if (fs.name()->equals("createNullPointerExceptionAddress")) {
            set_address("createNullPointerExceptionAddress", JVMCIRuntime::create_null_exception);
            assigned++;
            continue;
          }
          if (fs.name()->equals("gHotSpotVMTypeEntryTypeNameOffset")) {
            set_long("gHotSpotVMTypeEntryTypeNameOffset", gHotSpotVMTypeEntryTypeNameOffset);
            assigned++;
            continue;
          }
          if (fs.name()->equals("oopAlignedDisjointArraycopyUninit")) {
            set_long("oopAlignedDisjointArraycopyUninit", (long) (intptr_t) StubRoutines::_arrayof_oop_disjoint_arraycopy_uninit);
            assigned++;
            continue;
          }
          if (fs.name()->equals("createOutOfBoundsExceptionAddress")) {
            set_address("createOutOfBoundsExceptionAddress", JVMCIRuntime::create_out_of_bounds_exception);
            assigned++;
            continue;
          }
          continue;
        case 34:
          if (fs.name()->equals("gHotSpotVMStructEntryAddressOffset")) {
            set_long("gHotSpotVMStructEntryAddressOffset", gHotSpotVMStructEntryAddressOffset);
            assigned++;
            continue;
          }
          if (fs.name()->equals("gHotSpotVMTypeEntryIsOopTypeOffset")) {
            set_long("gHotSpotVMTypeEntryIsOopTypeOffset", gHotSpotVMTypeEntryIsOopTypeOffset);
            assigned++;
            continue;
          }
          continue;
        case 35:
          if (fs.name()->equals("gHotSpotVMTypeEntryIsUnsignedOffset")) {
            set_long("gHotSpotVMTypeEntryIsUnsignedOffset", gHotSpotVMTypeEntryIsUnsignedOffset);
            assigned++;
            continue;
          }
          if (fs.name()->equals("gHotSpotVMStructEntryTypeNameOffset")) {
            set_long("gHotSpotVMStructEntryTypeNameOffset", gHotSpotVMStructEntryTypeNameOffset);
            assigned++;
            continue;
          }
          if (fs.name()->equals("gHotSpotVMStructEntryIsStaticOffset")) {
            set_long("gHotSpotVMStructEntryIsStaticOffset", gHotSpotVMStructEntryIsStaticOffset);
            assigned++;
            continue;
          }
          continue;
        case 36:
          if (fs.name()->equals("gHotSpotVMStructEntryFieldNameOffset")) {
            set_long("gHotSpotVMStructEntryFieldNameOffset", gHotSpotVMStructEntryFieldNameOffset);
            assigned++;
            continue;
          }
          if (fs.name()->equals("gHotSpotVMIntConstantEntryNameOffset")) {
            set_long("gHotSpotVMIntConstantEntryNameOffset", gHotSpotVMIntConstantEntryNameOffset);
            assigned++;
            continue;
          }
          continue;
        case 37:
          if (fs.name()->equals("gHotSpotVMIntConstantEntryArrayStride")) {
            set_long("gHotSpotVMIntConstantEntryArrayStride", gHotSpotVMIntConstantEntryArrayStride);
            assigned++;
            continue;
          }
          if (fs.name()->equals("gHotSpotVMStructEntryTypeStringOffset")) {
            set_long("gHotSpotVMStructEntryTypeStringOffset", gHotSpotVMStructEntryTypeStringOffset);
            assigned++;
            continue;
          }
          if (fs.name()->equals("gHotSpotVMLongConstantEntryNameOffset")) {
            set_long("gHotSpotVMLongConstantEntryNameOffset", gHotSpotVMLongConstantEntryNameOffset);
            assigned++;
            continue;
          }
          if (fs.name()->equals("gHotSpotVMIntConstantEntryValueOffset")) {
            set_long("gHotSpotVMIntConstantEntryValueOffset", gHotSpotVMIntConstantEntryValueOffset);
            assigned++;
            continue;
          }
          continue;
        case 38:
          if (fs.name()->equals("cipherBlockChainingDecryptAESCryptStub")) {
            set_long("cipherBlockChainingDecryptAESCryptStub", (long) (intptr_t) StubRoutines::_cipherBlockChaining_decryptAESCrypt);
            assigned++;
            continue;
          }
          if (fs.name()->equals("cipherBlockChainingEncryptAESCryptStub")) {
            set_long("cipherBlockChainingEncryptAESCryptStub", (long) (intptr_t) StubRoutines::_cipherBlockChaining_encryptAESCrypt);
            assigned++;
            continue;
          }
          if (fs.name()->equals("gHotSpotVMTypeEntryIsIntegerTypeOffset")) {
            set_long("gHotSpotVMTypeEntryIsIntegerTypeOffset", gHotSpotVMTypeEntryIsIntegerTypeOffset);
            assigned++;
            continue;
          }
          if (fs.name()->equals("gHotSpotVMLongConstantEntryArrayStride")) {
            set_long("gHotSpotVMLongConstantEntryArrayStride", gHotSpotVMLongConstantEntryArrayStride);
            assigned++;
            continue;
          }
          if (fs.name()->equals("gHotSpotVMLongConstantEntryValueOffset")) {
            set_long("gHotSpotVMLongConstantEntryValueOffset", gHotSpotVMLongConstantEntryValueOffset);
            assigned++;
            continue;
          }
          continue;
        case 39:
          if (fs.name()->equals("exceptionHandlerForReturnAddressAddress")) {
            set_address("exceptionHandlerForReturnAddressAddress", SharedRuntime::exception_handler_for_return_address);
            assigned++;
            continue;
          }
          if (fs.name()->equals("gHotSpotVMTypeEntrySuperclassNameOffset")) {
            set_long("gHotSpotVMTypeEntrySuperclassNameOffset", gHotSpotVMTypeEntrySuperclassNameOffset);
            assigned++;
            continue;
          }
          continue;
      } // switch
      continue;
    } // if
  } // for
  guarantee(assigned == expected, "Didn't find all fields during init of HotSpotVMConfig.  Maybe recompile?");
}
